@@ -70,6 +70,11 @@ struct _GdaClientClass {
 extern GQuark gda_client_error_quark (void);
 #define GDA_CLIENT_ERROR gda_client_error_quark ()
 
+typedef enum
+{
+  GDA_CLIENT_GENERAL_ERROR
+} GdaClientError;
+
 GType          gda_client_get_type                           (void);
 GdaClient     *gda_client_new                                (void);
 
@@ -99,15 +104,6 @@ void           gda_client_notify_event                       (GdaClient *client,
 void           gda_client_notify_error_event                 (GdaClient *client, GdaConnection *cnc, GdaConnectionEvent *error);
 void           gda_client_notify_connection_opened_event     (GdaClient *client, GdaConnection *cnc);
 void           gda_client_notify_connection_closed_event     (GdaClient *client, GdaConnection *cnc);
-void           gda_client_notify_transaction_started_event   (GdaClient *client,
-							      GdaConnection *cnc,
-							      GdaTransaction *xaction);
-void           gda_client_notify_transaction_committed_event (GdaClient *client,
-							      GdaConnection *cnc,
-							      GdaTransaction *xaction);
-void           gda_client_notify_transaction_cancelled_event (GdaClient *client,
-							      GdaConnection *cnc,
-							      GdaTransaction *xaction);
 
 /*
  * General provider information
@@ -117,20 +113,21 @@ gchar         *gda_client_get_dsn_specs                      (GdaClient *client,
 /*
  * Database creation and destruction functions
  */
-GdaServerOperation *gda_client_prepare_create_database       (GdaClient *client, const gchar *provider);
-gboolean       gda_client_perform_create_database            (GdaClient *client, const gchar *provider, 
-							      GdaServerOperation *op, GError **error);
-GdaServerOperation *gda_client_prepare_drop_database         (GdaClient *client, const gchar *provider);
-gboolean       gda_client_perform_drop_database              (GdaClient *client, const gchar *provider,
-							      GdaServerOperation *op, GError **error);
+GdaServerOperation *gda_client_prepare_create_database       (GdaClient *client, const gchar *db_name, 
+							      const gchar *provider);
+gboolean       gda_client_perform_create_database            (GdaClient *client, GdaServerOperation *op, GError **error);
+GdaServerOperation *gda_client_prepare_drop_database         (GdaClient *client, const gchar *db_name, 
+							      const gchar *provider);
+gboolean       gda_client_perform_drop_database              (GdaClient *client, GdaServerOperation *op, GError **error);
 
 /*
  * Connection stack functions
  */
 
-gboolean       gda_client_begin_transaction                  (GdaClient *client, GdaTransaction *xaction);
-gboolean       gda_client_commit_transaction                 (GdaClient *client, GdaTransaction *xaction);
-gboolean       gda_client_rollback_transaction               (GdaClient *client, GdaTransaction *xaction);
+gboolean       gda_client_begin_transaction                  (GdaClient *client, const gchar *name, GdaTransactionIsolation level,
+							      GError **error);
+gboolean       gda_client_commit_transaction                 (GdaClient *client, const gchar *name, GError **error);
+gboolean       gda_client_rollback_transaction               (GdaClient *client, const gchar *name, GError **error);
 
 
 
