@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 1998 - 2006 The GNOME Foundation.
+ * Copyright (C) 1998 - 2007 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -38,6 +38,9 @@
 #ifdef HAVE_FAM
 #include <fam.h>
 #include <glib/giochannel.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #endif
 #ifdef LIBGDA_WIN32
 #include <io.h>
@@ -53,8 +56,6 @@ typedef struct {
 	gchar *name;
 	gchar *type;
 	gchar *value;
-	/* gchar *mtime; */
-	/* gchar *muser; */
 } GdaConfigEntry;
 
 typedef struct {
@@ -68,20 +69,27 @@ typedef struct {
 	GList *user;   /* list of GdaConfigSection */
 } GdaConfigClient;
 
-static GdaConfigClient *config_client;
+static GdaConfigClient *config_client = NULL;
 static gboolean         can_modif_global_conf; /* TRUE if the current user can modify the system wide config file */
 static gboolean         lock_write_notify = FALSE;
 static void             do_notify (const gchar *path);
 
+/* if @dsn_list_only_in_mem is TRUE, then the DSN list is not written to any file, but
+ * is just stored in memory, in @dsn_list_contents */
+static gboolean  dsn_list_only_in_mem = FALSE;
+
 /*
  * FAM delcarations and static variables
  */
 #ifdef HAVE_FAM
 static FAMConnection *fam_connection = NULL;
 static gint           fam_watch_id = 0;
-gboolean              lock_fam = FALSE;
-FAMRequest           *fam_conf_user = NULL;
-FAMRequest           *fam_conf_global = NULL;
+static gboolean       lock_fam = FALSE;
+static FAMRequest    *fam_conf_user = NULL;
+static FAMRequest    *fam_conf_global = NULL;
+static time_t         last_mtime = 0;
+static time_t         last_ctime = 0;
+static off_t          last_size = 0;
 
 static gboolean       fam_callback (GIOChannel *source, GIOCondition condition, gpointer data);
 static void           fam_lock_notify ();
@@ -123,21 +131,21 @@ gda_config_read_entries (xmlNodePtr cur)
 	list = NULL;
 	cur = cur->xmlChildrenNode;
 	while (cur != NULL){
-		if (!strcmp(cur->name, "entry")){
+		if (!strcmp((gchar*)cur->name, "entry")){
 			entry = g_new0 (GdaConfigEntry, 1);
-			entry->name = xmlGetProp(cur, "name");
+			entry->name = (gchar*)xmlGetProp(cur, (xmlChar*)"name");
 			if (entry->name == NULL){
 				g_warning ("NULL 'name' in an entry");
 				entry->name = g_strdup ("");
 			}
 
-			entry->type =  xmlGetProp(cur, "type");
+			entry->type = (gchar*)xmlGetProp(cur, (xmlChar*)"type");
 			if (entry->type == NULL){
 				g_warning ("NULL 'type' in an entry");
 				entry->type = g_strdup ("");
 			}
 
-			entry->value =  xmlGetProp(cur, "value");
+			entry->value = (gchar*)xmlGetProp(cur, (xmlChar*)"value");
 			if (entry->value == NULL){
 				g_warning ("NULL 'value' in an entry");
 				entry->value = g_strdup ("");
@@ -145,7 +153,7 @@ gda_config_read_entries (xmlNodePtr cur)
 
 			list = g_list_append (list, entry);
 		} else {
-			g_warning ("'entry' expected, got '%s'. Ignoring...", cur->name);
+			g_warning ("'entry' expected, got '%s'. Ignoring...", (gchar*)cur->name);
 		}
 		cur = cur->next;
 	}
@@ -206,8 +214,8 @@ gda_config_parse_config_file (gchar *buffer, gint len)
 		return NULL;
 	}
 
-	if (strcmp (cur->name, "libgda-config") != 0){
-		g_warning ("root node != 'libgda-config' -> '%s'", cur->name);
+	if (strcmp ((gchar*)cur->name, "libgda-config") != 0){
+		g_warning ("root node != 'libgda-config' -> '%s'", (gchar*)cur->name);
 		xmlFreeDoc (doc);
 		xmlMemSetup (old_free,
 			     old_malloc,
@@ -220,14 +228,14 @@ gda_config_parse_config_file (gchar *buffer, gint len)
 		if (xmlNodeIsText (cur)) 
 			continue;
 
-		if (strcmp (cur->name, "section")) {
-			if (strcmp (cur->name, "comment"))
-				g_warning ("'section' expected, got '%s'. Ignoring...", cur->name);
+		if (strcmp ((gchar*)cur->name, "section")) {
+			if (strcmp ((gchar*)cur->name, "comment"))
+				g_warning ("'section' expected, got '%s'. Ignoring...", (gchar*)cur->name);
 			continue;
 		}
 
 		section = g_new0 (GdaConfigSection, 1);
-		section->path = xmlGetProp (cur, "path");
+		section->path = (gchar*)xmlGetProp (cur, (xmlChar*)"path");
 		if (section->path != NULL &&
 		    !strncmp (section->path, section_path, sp_len)){
 			section->entries = gda_config_read_entries (cur);
@@ -260,10 +268,30 @@ get_config_client ()
 	 *	  wait until the operation finishes
 	 */
 	if (! config_client) {
-		gint len;
-		gchar *full_file;
+		guint len = 0;
+		gchar *full_file = NULL;
 		gchar *user_config = NULL;
-		gboolean has_user_config;
+		gboolean has_user_config = FALSE;
+		gchar *memonly;
+		
+		
+		config_client = g_new0 (GdaConfigClient, 1);
+		xmlKeepBlanksDefault(0);
+
+		/* check if DSN list should only be stored in memory */
+		memonly = getenv ("GDA_DSN_LIST_IN_MEMORY");
+		if (memonly) {
+			gsize length;
+			gchar *init_contents;
+			dsn_list_only_in_mem = TRUE;
+
+			g_print ("** DSN list will remain in memory and will be lost at the end of the session **\n");
+			if (*memonly && g_file_get_contents (memonly, &init_contents, &length, NULL)) {
+				config_client->user = gda_config_parse_config_file (init_contents, length);
+				g_free (init_contents);
+			}
+			return config_client;
+		}
 
 		has_user_config = g_get_home_dir () ? TRUE : FALSE;
 		if (has_user_config)
@@ -276,14 +304,14 @@ get_config_client ()
 			file = fopen (LIBGDA_GLOBAL_CONFIG_FILE, "a");
 			if (file) {
 				can_modif_global_conf = TRUE;
-#ifdef GDA_DEBUG
+#ifdef GDA_DEBUG_NO
 				g_print ("Can write system wide config file\n");
 #endif
 				fclose (file);
 			}
 			else {
 				can_modif_global_conf = FALSE;
-#ifdef GDA_DEBUG
+#ifdef GDA_DEBUG_NO
 				g_print ("Cannot write system wide config file\n");
 #endif			
 			}
@@ -295,7 +323,7 @@ get_config_client ()
 			GIOChannel *ioc;
 			int res;
 	
-#ifdef GDA_DEBUG
+#ifdef GDA_DEBUG_NO
 			g_print ("Using FAM to monitor configuration files changes.\n");
 #endif
 			fam_connection = g_malloc0 (sizeof (FAMConnection));
@@ -313,7 +341,7 @@ get_config_client ()
 				fam_conf_global = g_new0 (FAMRequest, 1);
 				res = FAMMonitorFile (fam_connection, LIBGDA_GLOBAL_CONFIG_FILE, fam_conf_global, 
 						      GINT_TO_POINTER (TRUE));
-#ifdef GDA_DEBUG
+#ifdef GDA_DEBUG_NO
 				g_print ("Monitoring changes on file %s: %s\n", 
 					 LIBGDA_GLOBAL_CONFIG_FILE, res ? "ERROR" : "Ok");
 #endif
@@ -322,7 +350,7 @@ get_config_client ()
 					fam_conf_user = g_new0 (FAMRequest, 1);
 					res = FAMMonitorFile (fam_connection, user_config, fam_conf_user, 
 							      GINT_TO_POINTER (FALSE));
-#ifdef GDA_DEBUG
+#ifdef GDA_DEBUG_NO
 					g_print ("Monitoring changes on file %s: %s\n", 
 						 user_config, res ? "ERROR" : "Ok");
 #endif
@@ -331,9 +359,6 @@ get_config_client ()
 			
 		}
 #endif
-		
-		config_client = g_new0 (GdaConfigClient, 1);
-		xmlKeepBlanksDefault(0);
 
 		/*
 		 * load system wide config
@@ -468,7 +493,20 @@ fam_callback (GIOChannel *source, GIOCondition condition, gpointer data)
 
 		is_global = GPOINTER_TO_INT (ev.userdata);
 		switch (ev.code) {
-		case FAMChanged:
+		case FAMChanged: {
+			struct stat stat;
+			if (lstat (ev.filename, &stat))
+				break;
+			if ((stat.st_mtime != last_mtime) ||
+			    (stat.st_ctime != last_ctime) ||
+			    (stat.st_size != last_size)) {
+				last_mtime = stat.st_mtime;
+				last_ctime = stat.st_ctime;
+				last_size = stat.st_size;
+			}
+			else
+				break;
+		}
 		case FAMDeleted:
 		case FAMCreated:
 #ifdef GDA_DEBUG_NO
@@ -655,10 +693,10 @@ add_xml_entry (xmlNodePtr parent, GdaConfigEntry *entry)
 {
 	xmlNodePtr new_node;
 
-	new_node = xmlNewTextChild (parent, NULL, "entry", NULL);
-	xmlSetProp (new_node, "name", entry->name);
-	xmlSetProp (new_node, "type", entry->type);
-	xmlSetProp (new_node, "value", entry->value);
+	new_node = xmlNewTextChild (parent, NULL, (xmlChar*)"entry", NULL);
+	xmlSetProp (new_node, (xmlChar*)"name", (xmlChar*)entry->name);
+	xmlSetProp (new_node, (xmlChar*)"type", (xmlChar*)entry->type);
+	xmlSetProp (new_node, (xmlChar*)"value", (xmlChar*)entry->value);
 }
 
 static xmlNodePtr
@@ -666,8 +704,8 @@ add_xml_section (xmlNodePtr parent, GdaConfigSection *section)
 {
 	xmlNodePtr new_node;
 
-	new_node = xmlNewTextChild (parent, NULL, "section", NULL);
-	xmlSetProp (new_node, "path", section->path ? section->path : "");
+	new_node = xmlNewTextChild (parent, NULL, (xmlChar*)"section", NULL);
+	xmlSetProp (new_node, (xmlChar*)"path", (xmlChar*)(section->path ? section->path : ""));
 	return new_node;
 }
 
@@ -687,11 +725,15 @@ write_config_file ()
 	if (lock_write_notify)
 		return;
 
+	if (dsn_list_only_in_mem)
+		/* nothing to do */
+		return;
+
 	/* user specific data sources */
 	cfg_client = get_config_client ();
-	doc = xmlNewDoc ("1.0");
+	doc = xmlNewDoc ((xmlChar*)"1.0");
 	g_return_if_fail (doc != NULL);
-	root = xmlNewDocNode (doc, NULL, "libgda-config", NULL);
+	root = xmlNewDocNode (doc, NULL, (xmlChar*)"libgda-config", NULL);
 	xmlDocSetRootElement (doc, root);
 	for (ls = cfg_client->user; ls; ls = ls->next){
 		section = ls->data;
@@ -722,9 +764,9 @@ write_config_file ()
 
 	/* system wide data sources */
 	if (can_modif_global_conf) {
-		doc = xmlNewDoc ("1.0");
+		doc = xmlNewDoc ((xmlChar*)"1.0");
 		g_return_if_fail (doc != NULL);
-		root = xmlNewDocNode (doc, NULL, "libgda-config", NULL);
+		root = xmlNewDocNode (doc, NULL, (xmlChar*)"libgda-config", NULL);
 		xmlDocSetRootElement (doc, root);
 		for (ls = cfg_client->global; ls; ls = ls->next){
 			section = ls->data;
@@ -1744,7 +1786,7 @@ gda_config_find_data_source (const gchar *name)
 	for (l = dsnlist; l != NULL; l = l->next) {
 		GdaDataSourceInfo *tmp_info = (GdaDataSourceInfo *) l->data;
 
-		if (tmp_info && !g_strcasecmp (tmp_info->name, name)) {
+		if (tmp_info && !g_ascii_strcasecmp (tmp_info->name, name)) {
 			info = gda_data_source_info_copy (tmp_info);
 			break;
 		}
@@ -1863,9 +1905,8 @@ gda_config_free_data_source_list (GList *list)
  * Fills and returns a new #GdaDataModel object using information from all 
  * data sources which are currently configured in the system.
  *
- * Rows are separated in 7 columns: 
- * 'Name', 'Provider', 'Connection string', 'Description', 'Username',
- * 'Password' and 'Global'.
+ * Rows are separated in 6 columns: 
+ * 'Name', 'Provider', 'Connection string', 'Description', 'Username' and 'Global'.
  *
  * Returns: a new #GdaDataModel object. 
  */
@@ -1876,14 +1917,13 @@ gda_config_get_data_source_model (void)
 	GList *l;
 	GdaDataModel *model;
 
-	model = gda_data_model_array_new (7);
+	model = gda_data_model_array_new (6);
 	gda_data_model_set_column_title (model, 0, _("Name"));
 	gda_data_model_set_column_title (model, 1, _("Provider"));
 	gda_data_model_set_column_title (model, 2, _("Connection string"));
 	gda_data_model_set_column_title (model, 3, _("Description"));
 	gda_data_model_set_column_title (model, 4, _("Username"));
-	gda_data_model_set_column_title (model, 5, _("Password"));
-	gda_data_model_set_column_title (model, 6, _("Global"));
+	gda_data_model_set_column_title (model, 5, _("Global"));
 	
 	/* convert the returned GList into a GdaDataModelArray */
 	dsn_list = gda_config_get_data_source_list ();
@@ -1914,10 +1954,6 @@ gda_config_get_data_source_model (void)
 		g_value_set_string (value, dsn_info->username);
 		value_list = g_list_append (value_list, value);
 
-		value = g_value_init (g_new0 (GValue, 1), G_TYPE_STRING);
-		g_value_set_string (value, "******");
-		value_list = g_list_append (value_list, value);
-
 		value = g_value_init (g_new0 (GValue, 1), G_TYPE_BOOLEAN);
 		g_value_set_boolean (value, dsn_info->is_global);
 		value_list = g_list_append (value_list, value);
@@ -2032,13 +2068,15 @@ gda_config_save_data_source (const gchar *name,
 	g_assert (section);
 	section->is_global = is_global;
 
-	cfg_client->user = g_list_remove (cfg_client->user, section);
-	cfg_client->global = g_list_remove (cfg_client->global, section);
-
-	if (!g_list_find (cfg_client->global, section) && is_global)
+	if (section->is_global && (!g_list_find (cfg_client->global, section))) {
 		cfg_client->global = g_list_append (cfg_client->global, section);
-	if (!g_list_find (cfg_client->user, section) && !is_global)
+		cfg_client->user = g_list_remove (cfg_client->user, section);
+	}
+
+	if (!section->is_global && (!g_list_find (cfg_client->user, section))) {
 		cfg_client->user = g_list_append (cfg_client->user, section);
+		cfg_client->global = g_list_remove (cfg_client->global, section);
+	}
 
 	g_string_free (str, TRUE);
 
