@@ -31,23 +31,23 @@
 #include <libgda/gda-decl.h>
 #include <libgda/gda-column.h>
 #include <libgda/gda-value.h>
+#include <libgda/gda-data-model-extra.h>
 
 G_BEGIN_DECLS
 
-void                          gda_data_model_changed                (GdaDataModel *model);
-void                          gda_data_model_row_inserted           (GdaDataModel *model, gint row);
-void                          gda_data_model_row_updated            (GdaDataModel *model, gint row);
-void                          gda_data_model_row_removed            (GdaDataModel *model, gint row);
-
 const gchar                  *gda_data_model_get_command_text       (GdaDataModel *model);
 gboolean                      gda_data_model_set_command_text       (GdaDataModel *model, const gchar *txt);
 GdaCommandType                gda_data_model_get_command_type       (GdaDataModel *model);
 gboolean                      gda_data_model_set_command_type       (GdaDataModel *model, GdaCommandType type);
 
 xmlNodePtr                    gda_data_model_to_xml_node            (GdaDataModel *model, const gint *cols, gint nb_cols, 
-								     const gchar *name);
+								     const gint *rows, gint nb_rows, const gchar *name);
 gboolean                      gda_data_model_add_data_from_xml_node (GdaDataModel *model, xmlNodePtr node, GError **error);
 
+gboolean                      gda_data_model_move_iter_at_row       (GdaDataModel *model, GdaDataModelIter *iter, gint row);
+gboolean                      gda_data_model_move_iter_next         (GdaDataModel *model, GdaDataModelIter *iter);
+gboolean                      gda_data_model_move_iter_prev         (GdaDataModel *model, GdaDataModelIter *iter);
+
 G_END_DECLS
 
 #endif
