@@ -100,7 +100,6 @@ enum
 {
 	PROP_0,
 	PROP_MODEL,
-	PROP_AUTOCOMMIT,
 	PROP_ADD_NULL_ENTRY,
 };
 
@@ -126,7 +125,7 @@ typedef struct
 	RowModif      *row_modif;    /* RowModif in which this structure instance appears */
 	gint           model_column; /* column index in the GdaDataModel */
         GValue        *value;        /* can also be GDA_TYPE_LIST for multiple values; values are owned here */
-        GValue        *attributes;   /* holds a GUINT of GValueAttribute */
+        GValue        *attributes;   /* holds a GUINT of GdaValueAttribute */
 } RowValue;
 #define ROW_VALUE(x) ((RowValue *)(x))
 
@@ -147,12 +146,10 @@ typedef struct
 struct _GdaDataProxyPrivate
 {
 	GdaDataModel      *model; /* Gda model which is proxied */
-	GValue           **columns_attrs; /* Each GValue holds a GUINT of GValueAttribute to proxy cols. attributes */
+	GValue           **columns_attrs; /* Each GValue holds a GUINT of GdaValueAttribute to proxy cols. attributes */
 
 	gint               model_nb_cols; /* = gda_data_model_get_n_columns (model) */
-	gboolean           autocommit;
 	gboolean           notify_changes;
-	guint              background_commit_id;
 
 	GSList            *all_modifs; /* list of RowModif structures, for memory management */
 	GSList            *new_rows;   /* list of RowModif, no data allocated in this list */
@@ -160,6 +157,9 @@ struct _GdaDataProxyPrivate
 
 	gboolean           ignore_proxied_changes;
 	gboolean           proxy_has_changed;
+	gint               deferred_nb_rows; /* if >0 it means that the proxy "advertises" more rows than it really has,
+						it can only be a transitory state, to avoid remoing new rows when
+						they have been comitted */
 
 	gboolean           add_null_entry; /* artificially add a NULL entry at the beginning of the tree model */
 
@@ -173,38 +173,8 @@ struct _GdaDataProxyPrivate
 	
 	/* for ALL the columns of proxy */
 	GdaColumn        **columns;
-
-	/* attributes to implement the gda_data_proxy_store_model_row_value() and similar functions */
-	GHashTable        *extra_store; /* key = (model,col), value = a GValue */
 };
 
-/*
- * Functions specific for proxy->priv->extra_store
- */
-typedef struct {
-	GdaDataModel *model;
-	gint          col;
-} ExtraStore;
-
-static guint
-custom_hash_func (ExtraStore *es)
-{
-	guint ret;
-
-	ret = GPOINTER_TO_UINT (es->model);
-	ret += (es->col) << 16;
-
-	return ret;
-}
-
-static gboolean
-custom_equal_func (ExtraStore *es1, ExtraStore *es2)
-{
-	if ((es1->model == es2->model) && (es1->col == es2->col))
-		return TRUE;
-	else
-		return FALSE;
-}
 
 /*
  * The model_row_to_proxy_row() and proxy_row_to_model_row() convert row numbers between GdaDataModel
@@ -267,6 +237,7 @@ find_row_modif_for_proxy_row (GdaDataProxy *proxy, gint proxy_row)
 	return rm;
 }
 
+/* Not used:
 static gint
 find_proxy_row_for_row_modif (GdaDataProxy *proxy, RowModif *rm)
 {
@@ -280,6 +251,7 @@ find_proxy_row_for_row_modif (GdaDataProxy *proxy, RowModif *rm)
 			(proxy->priv->add_null_entry ? 1 : 0);
 	}
 }
+*/
 
 /*
  * Free a RowModif structure
@@ -336,10 +308,13 @@ row_modifs_new (GdaDataProxy *proxy, gint proxy_row)
 		rm->orig_values_size = proxy->priv->model_nb_cols;
 		model_row = proxy_row_to_model_row (proxy, proxy_row);
 		
-		for (i=0; i<proxy->priv->model_nb_cols; i++)
-			rm->orig_values [i] = 
-				gda_value_copy ((GValue *)gda_data_proxy_get_value_at ((GdaDataModel *)proxy, 
-											 i, model_row));
+		for (i=0; i<proxy->priv->model_nb_cols; i++) {
+			const GValue *oval;
+
+			oval = gda_data_proxy_get_value_at ((GdaDataModel *)proxy, i, model_row);
+			if (oval)
+				rm->orig_values [i] = gda_value_copy ((GValue *) oval);
+		}
 	}
 	
 	return rm;
@@ -432,51 +407,15 @@ gda_data_proxy_class_init (GdaDataProxyClass *class)
 	object_class->get_property = gda_data_proxy_get_property;
 
 	g_object_class_install_property (object_class, PROP_MODEL,
-					 g_param_spec_pointer ("model", _("Data model"), NULL,
+					 g_param_spec_object ("model", _("Data model"), NULL,
+                                                               GDA_TYPE_DATA_MODEL,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE |
 								G_PARAM_CONSTRUCT_ONLY)));
-	g_object_class_install_property (object_class, PROP_AUTOCOMMIT,
-					 g_param_spec_boolean ("autocommit", NULL, NULL, FALSE,
-							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_ADD_NULL_ENTRY,
 					 g_param_spec_boolean ("prepend_null_entry", NULL, NULL, FALSE,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 }
 
-static gboolean
-background_commit_cb (GdaDataProxy *proxy)
-{
-	if (proxy->priv) {
-		GError *error = NULL;
-
-		if (!gda_data_proxy_apply_all_changes (proxy, &error)) {
-			g_warning (_("Could not auto-commit row change: %s"), 
-				   error && error->message ?  error->message : _("No detail"));
-			if (error)
-				g_error_free (error);
-		}
-		proxy->priv->background_commit_id = 0;
-	}
-	return FALSE;
-}
-
-static void
-row_changed_signal (GdaDataModel *model, gint row)
-{
-	GdaDataProxy *proxy;
-
-	proxy = GDA_DATA_PROXY (model);
-	if (!proxy->priv)
-		return;
-
-	/* the changes will be committed later in an idle high priority loop */
-	if (proxy->priv->autocommit && !proxy->priv->background_commit_id) {
-		proxy->priv->background_commit_id = g_timeout_add_full (G_PRIORITY_HIGH_IDLE, 10,
-									(GSourceFunc) background_commit_cb, 
-									proxy, NULL);
-	}
-}
-
 static void
 gda_data_proxy_data_model_init (GdaDataModelClass *iface)
 {
@@ -503,9 +442,9 @@ gda_data_proxy_data_model_init (GdaDataModelClass *iface)
 	iface->i_get_notify = gda_data_proxy_get_notify;
 	iface->i_send_hint = gda_data_proxy_send_hint;
 
-	iface->row_inserted = row_changed_signal;
-	iface->row_updated = row_changed_signal;
-	iface->row_removed = row_changed_signal;
+	iface->row_inserted = NULL;
+	iface->row_updated = NULL;
+	iface->row_removed = NULL;
 }
 
 static void
@@ -519,17 +458,12 @@ gda_data_proxy_init (GdaDataProxy *proxy)
 
 	proxy->priv->add_null_entry = FALSE;
 	proxy->priv->idle_add_event_source = 0;
-	proxy->priv->background_commit_id = 0;
 
 	proxy->priv->sample_first_row = 0;
 	proxy->priv->sample_last_row = 0;
 	proxy->priv->sample_size = 300;
 	proxy->priv->current_nb_rows = 0;
 	proxy->priv->columns = NULL;
-
-	proxy->priv->extra_store = g_hash_table_new_full ((GHashFunc) custom_hash_func, 
-							  (GEqualFunc) custom_equal_func,
-							  g_free, (GDestroyNotify) gda_value_free);
 }
 
 static void adjust_displayed_chunck (GdaDataProxy *proxy);
@@ -614,11 +548,6 @@ gda_data_proxy_dispose (GObject *object)
 			g_hash_table_destroy (proxy->priv->modif_rows);
 			proxy->priv->modif_rows = NULL;
 		}
-
-		if (proxy->priv->extra_store) {
-			g_hash_table_destroy (proxy->priv->extra_store);
-			proxy->priv->extra_store = NULL;
-		}
 	}
 
 	/* parent class */
@@ -665,7 +594,7 @@ gda_data_proxy_set_property (GObject *object,
 		switch (param_id) {
 		case PROP_MODEL:
 			g_assert (!proxy->priv->model);
-			model = (GdaDataModel*) g_value_get_pointer (value);
+			model = (GdaDataModel*) g_value_get_object (value);
 			g_return_if_fail (GDA_IS_DATA_MODEL (model));
 
 			if (! (gda_data_model_get_access_flags (model) & GDA_DATA_MODEL_ACCESS_RANDOM)) {
@@ -701,9 +630,6 @@ gda_data_proxy_set_property (GObject *object,
 			
 			adjust_displayed_chunck (proxy);
 			break;
-		case PROP_AUTOCOMMIT:
-			proxy->priv->autocommit = g_value_get_boolean (value);
-			break;
 		case PROP_ADD_NULL_ENTRY:
 			if (proxy->priv->add_null_entry != g_value_get_boolean (value)) {
 				proxy->priv->add_null_entry = g_value_get_boolean (value);
@@ -729,9 +655,6 @@ gda_data_proxy_get_property (GObject *object,
 	proxy = GDA_DATA_PROXY (object);
 	if (proxy->priv) {
 		switch (param_id) {
-		case PROP_AUTOCOMMIT:
-			g_value_set_boolean (value, proxy->priv->autocommit);
-			break;
 		case PROP_ADD_NULL_ENTRY:
 			g_value_set_boolean (value, proxy->priv->add_null_entry);
 			break;
@@ -751,6 +674,7 @@ gda_data_proxy_get_property (GObject *object,
 static void
 proxied_model_data_changed_cb (GdaDataModel *model, GdaDataProxy *proxy)
 {
+	gint nb_new_rows = 0;
 	if (proxy->priv->ignore_proxied_changes) {
 		proxy->priv->proxy_has_changed = TRUE;
 		return;
@@ -772,14 +696,7 @@ proxied_model_data_changed_cb (GdaDataModel *model, GdaDataProxy *proxy)
 		proxy->priv->all_modifs = g_slist_delete_link (proxy->priv->all_modifs, proxy->priv->all_modifs);
 	}
 	if (proxy->priv->new_rows) {/* new rows removing (no memory de-allocation here, though) */
-		gint i, j, rowsig;
-		j = g_slist_length (proxy->priv->new_rows);
-		rowsig = proxy->priv->current_nb_rows + (proxy->priv->add_null_entry ? 1 : 0);
-		/* emit a "delete" signal USING the SAME row number for all of them */
-		for (i = 0; i < j ; i++) {
-			if (proxy->priv->notify_changes)
-				gda_data_model_row_removed ((GdaDataModel *) proxy, rowsig);
-		}
+		nb_new_rows = g_slist_length (proxy->priv->new_rows);
 		g_slist_free (proxy->priv->new_rows);
 		proxy->priv->new_rows = NULL;
 	}
@@ -795,6 +712,7 @@ proxied_model_data_changed_cb (GdaDataModel *model, GdaDataProxy *proxy)
 		g_assert_not_reached ();
 	}
 
+	proxy->priv->deferred_nb_rows += nb_new_rows;
 	adjust_displayed_chunck (proxy);
 }
 
@@ -952,7 +870,7 @@ gda_data_proxy_get_values (GdaDataProxy *proxy, gint proxy_row, gint *cols_index
  * @col: a valid proxy column
  *
  * Get the attributes of the value stored at (proxy_row, col) in @proxy, which
- * is an ORed value of #GValueAttribute flags
+ * is an ORed value of #GdaValueAttribute flags
  *
  * Returns: the attribute
  */
@@ -971,10 +889,12 @@ gda_data_proxy_get_value_attributes (GdaDataProxy *proxy, gint proxy_row, gint c
 
 	model_column = col % proxy->priv->model_nb_cols;
 	model_row = proxy_row_to_model_row (proxy, proxy_row);
-	if (model_row >= 0)
-		flags = gda_data_model_get_attributes_at (proxy->priv->model, model_column, model_row);
-	else
-		flags = GDA_VALUE_ATTR_IS_NULL;
+	flags = gda_data_model_get_attributes_at (proxy->priv->model, model_column, model_row);
+	if (model_row < 0) {
+		flags |= GDA_VALUE_ATTR_IS_NULL;
+		if (flags & GDA_VALUE_ATTR_NO_MODIF) /* A new row with unmodifiable data means unused data */
+			flags |= GDA_VALUE_ATTR_UNUSED;
+	}
 
 	rm = find_row_modif_for_proxy_row (proxy, proxy_row);
 	if (rm) {
@@ -991,7 +911,6 @@ gda_data_proxy_get_value_attributes (GdaDataProxy *proxy, gint proxy_row, gint c
 			}
 			if (rv) {
 				value_has_modifs = TRUE;
-				flags &= ~GDA_VALUE_ATTR_NO_MODIF; /* filter only that attribute */
 				flags |= g_value_get_uint (rv->attributes);
 				if (rv->value && !gda_value_is_null (rv->value))
 					flags &= ~GDA_VALUE_ATTR_IS_NULL;
@@ -1009,7 +928,7 @@ gda_data_proxy_get_value_attributes (GdaDataProxy *proxy, gint proxy_row, gint c
 		if ((flags & GDA_VALUE_ATTR_IS_NULL) && !(flags & GDA_VALUE_ATTR_IS_DEFAULT))
 			flags |= GDA_VALUE_ATTR_DATA_NON_VALID;
 	}
-	
+
 	return flags;
 }
 
@@ -1064,8 +983,13 @@ gda_data_proxy_alter_value_attributes (GdaDataProxy *proxy, gint proxy_row, gint
 				
 				rm->modif_values = g_slist_prepend (rm->modif_values, rv);	
 			}
-			else
+			else {
 				flags = g_value_get_uint (rv->attributes);
+				if (rv->value) {
+					gda_value_free (rv->value);
+					rv->value = NULL;
+				}
+			}
 			flags |= GDA_VALUE_ATTR_IS_DEFAULT;
 			g_value_set_uint (rv->attributes, flags);
 
@@ -1380,11 +1304,16 @@ gda_data_proxy_append (GdaDataProxy *proxy)
 		def = gda_column_get_default_value (column);
 		if (def) {
 			flags |= (GDA_VALUE_ATTR_IS_DEFAULT | GDA_VALUE_ATTR_CAN_BE_DEFAULT);
-			if (G_VALUE_TYPE (def) == gda_column_get_gda_type (column))
+			if (G_VALUE_TYPE (def) == gda_column_get_g_type (column))
 				rv->value = gda_value_copy (def);
 		}
-		if (gda_column_get_allow_null (column))
-			flags |= GDA_VALUE_ATTR_CAN_BE_NULL;
+		if (gda_column_get_allow_null (column)) {
+			guint attributes;
+			
+			attributes = gda_data_model_get_attributes_at (proxy->priv->model, col, -1);;
+			if (attributes & GDA_VALUE_ATTR_CAN_BE_NULL)
+				flags |= GDA_VALUE_ATTR_CAN_BE_NULL;
+		}
 
 		if (gda_column_get_auto_increment (column))
 			flags |= (GDA_VALUE_ATTR_IS_DEFAULT | GDA_VALUE_ATTR_CAN_BE_DEFAULT);
@@ -1402,11 +1331,10 @@ gda_data_proxy_append (GdaDataProxy *proxy)
 /**
  * gda_data_proxy_cancel_row_changes
  * @proxy: a #GdaDataProxy object
- * @col:
- * @row:
+ * @col: the column to cancel changes, or less than 0 to cancel any change on the @row row
+ * @row: the row to cancel changes
  *
- * Resets data at the corresponding row and column. @row and @col can be <0 if all the corresponding
- * rows and columns are to be resetted.
+ * Resets data at the corresponding row and column.
  */
 void
 gda_data_proxy_cancel_row_changes (GdaDataProxy *proxy, gint proxy_row, gint col)
@@ -1415,7 +1343,8 @@ gda_data_proxy_cancel_row_changes (GdaDataProxy *proxy, gint proxy_row, gint col
 	g_return_if_fail (proxy->priv);
 	g_return_if_fail (proxy_row >= 0);
 
-	if ((col >= 0) && (col < proxy->priv->model_nb_cols)) {
+	if (((col >= 0) && (col < proxy->priv->model_nb_cols)) ||
+	    (col < 0)) {
 		RowModif *rm;
 
 		rm = find_row_modif_for_proxy_row (proxy, proxy_row);
@@ -1425,30 +1354,36 @@ gda_data_proxy_cancel_row_changes (GdaDataProxy *proxy, gint proxy_row, gint col
 			RowValue *rv = NULL;
 			
 			list = rm->modif_values;
-			while (list && !rv) {
-				if (ROW_VALUE (list->data)->model_column == col)
+			while (list && (!rv || (col < 0))) {
+				if ((col < 0) || (ROW_VALUE (list->data)->model_column == col)) {
 					rv = ROW_VALUE (list->data);
-				list = g_slist_next (list);
-			}
-			if (rv) {
-				/* remove this RowValue from the RowList */
-				rm->modif_values = g_slist_remove (rm->modif_values, rv);
-				if (!rm->modif_values && !rm->to_be_deleted) {
-					/* remove this RowList as well */
-					proxy->priv->all_modifs = g_slist_remove (proxy->priv->all_modifs, rm);
-					if (rm->model_row < 0) 
-						proxy->priv->new_rows = g_slist_remove (proxy->priv->new_rows, rm);
-					else
-						g_hash_table_remove (proxy->priv->modif_rows, GINT_TO_POINTER (rm->model_row));
-					row_modifs_free (rm);
 
-					if (proxy->priv->notify_changes)
-						gda_data_model_row_removed ((GdaDataModel *) proxy, proxy_row);
-				}
-				else {
-					if (proxy->priv->notify_changes)
-						gda_data_model_row_updated ((GdaDataModel *) proxy, proxy_row);
+					/* remove this RowValue from the RowList */
+					rm->modif_values = g_slist_remove (rm->modif_values, rv);
+					if (!rm->modif_values && !rm->to_be_deleted) {
+						/* remove this RowList as well */
+						proxy->priv->all_modifs = g_slist_remove (proxy->priv->all_modifs, rm);
+						if (rm->model_row < 0) 
+							proxy->priv->new_rows = g_slist_remove (proxy->priv->new_rows, rm);
+						else
+							g_hash_table_remove (proxy->priv->modif_rows, GINT_TO_POINTER (rm->model_row));
+						row_modifs_free (rm);
+						rm = NULL;
+						
+						if (proxy->priv->notify_changes)
+							gda_data_model_row_removed ((GdaDataModel *) proxy, proxy_row);
+					}
+					else {
+						if (proxy->priv->notify_changes)
+							gda_data_model_row_updated ((GdaDataModel *) proxy, proxy_row);
+					}
+					if (rm)
+						list = rm->modif_values;
+					else
+						list = NULL;
 				}
+				else
+					list = list->next;
 			}
 		}
 	}
@@ -1608,17 +1543,14 @@ commit_row_modif (GdaDataProxy *proxy, RowModif *rm, GError **error)
 			g_free (free_val);
 
 			if (!err) {
-				/* emit a "delete" signal for that row because when rm is
-				 * removed it means the corresponding row will have been removed,
-				 * and if we don't emit that signal, then there will be a problem. 
+				/* Don't yet emit a "delete" signal for that row, but increment 
+				 * proxy->priv->deferred_nb_rows
 				 */
-				gint rowsig = find_proxy_row_for_row_modif (proxy, rm);
-
 				proxy->priv->all_modifs = g_slist_remove (proxy->priv->all_modifs, rm);
 				proxy->priv->new_rows = g_slist_remove (proxy->priv->new_rows, rm);
 				row_modifs_free (rm);
 
-				gda_data_model_row_removed ((GdaDataModel *) proxy, rowsig);
+				proxy->priv->deferred_nb_rows ++;
 				freedone = TRUE;
 			}
 		}
@@ -1634,8 +1566,8 @@ commit_row_modif (GdaDataProxy *proxy, RowModif *rm, GError **error)
 	proxy->priv->ignore_proxied_changes = ignore_proxied_changes;
 	if (proxy->priv->proxy_has_changed) 
 		proxied_model_data_changed_cb (proxy->priv->model, proxy);
-
-	adjust_displayed_chunck (proxy);
+	else
+		adjust_displayed_chunck (proxy);
 
 	return !err;
 }
@@ -1815,7 +1747,9 @@ gda_data_proxy_get_sample_end (GdaDataProxy *proxy)
 
 /*
  * Adjusts the values of the first and last rows to be displayed depending
- * on the sample size
+ * on the sample size.
+ *
+ * Some rows may be added or removed during the adjustment.
  */
 static void
 adjust_displayed_chunck (GdaDataProxy *proxy)
@@ -1843,7 +1777,9 @@ adjust_displayed_chunck (GdaDataProxy *proxy)
 	old_start = proxy->priv->sample_first_row;
 	old_end = proxy->priv->sample_last_row;
 
-	old_nb_rows = proxy->priv->current_nb_rows;
+	old_nb_rows = proxy->priv->current_nb_rows + proxy->priv->deferred_nb_rows;
+	proxy->priv->deferred_nb_rows = 0;
+
 	model_nb_rows = gda_data_model_get_n_rows (proxy->priv->model);
 
 	if (model_nb_rows > 0) {
@@ -1942,7 +1878,7 @@ adjust_displayed_chunck (GdaDataProxy *proxy)
 	/* re-enable the emision of the "changed" signal each time a "row_*" signal is
 	 * emitted */
 	gda_object_unblock_changed (GDA_OBJECT (proxy));
-	gda_data_model_changed ((GdaDataModel *) proxy);
+	gda_data_model_signal_emit_changed ((GdaDataModel *) proxy);
 
 #ifdef GDA_DEBUG_NO
 	g_print ("//GdaDataProxy adjusted sample: %d<->%d (=%d / %d rows, %s)\n", proxy->priv->sample_first_row, 
@@ -2106,167 +2042,6 @@ gda_data_proxy_cancel_all_changes (GdaDataProxy *proxy)
 }
 
 
-static void
-store_dump_foreach (ExtraStore *key, GValue *value, gpointer data)
-{
-	g_print ("%p, C=%d, val= %s\n", key->model, key->col, gda_value_stringify (value));
-}
-
-static void
-dump_extra_store (GdaDataProxy *proxy)
-{
-	g_hash_table_foreach (proxy->priv->extra_store, (GHFunc) store_dump_foreach, NULL);
-}
-
-/**
- * gda_data_proxy_get_model_row_value
- * @proxy: a #GdaDataProxy object
- * @model: a #GdaDataModel object
- * @proxy_row: a valid row number in @proxy
- * @col:
- * 
- * Retreive a value stored in @proxy using the gda_data_proxy_store_extra_value() method
- * 
- * Returns: the stored #GValue, or %NULL if no value was stored.
- */
-const GValue *
-gda_data_proxy_get_model_row_value (GdaDataProxy *proxy, GdaDataModel *model, gint proxy_row, gint extra_col)
-{
-	ExtraStore es;
-	const GValue *value = NULL;
-
-	g_return_val_if_fail (GDA_IS_DATA_PROXY (proxy), NULL);
-	g_return_val_if_fail (proxy->priv, NULL);
-
-	es.model = model;
-	es.col = extra_col;
-	value = g_hash_table_lookup (proxy->priv->extra_store, &es);
-	if (value) {
-		gint proxy_col;
-		proxy_col = g_value_get_int ((GValue *) value);
-		value = gda_data_model_get_value_at ((GdaDataModel *) proxy, proxy_col, proxy_row);
-	}
-	
-	return value;
-}
-
-/**
- * gda_data_proxy_set_model_row_value
- * @proxy: a #GdaDataProxy object
- * @model: a #GdaDataModel object
- * @proxy_row: a valid row number in @proxy
- * @col:
- * @value:
- * 
- * Retreive a value stored in @proxy using the gda_data_proxy_store_extra_value() method
- * 
- * Returns: the stored #GValue, or %NULL if no value was stored.
- */
-void
-gda_data_proxy_set_model_row_value (GdaDataProxy *proxy, GdaDataModel *model, 
-				    gint proxy_row, gint extra_col, const GValue *value)
-{
-	ExtraStore es;
-	const GValue *colval;
-
-	g_return_if_fail (GDA_IS_DATA_PROXY (proxy));
-	g_return_if_fail (proxy->priv);
-
-	es.model = model;
-	es.col = extra_col;
-	colval = g_hash_table_lookup (proxy->priv->extra_store, &es);
-	if (colval) {
-		gint proxy_col;
-
-		proxy_col = g_value_get_int ((GValue *) colval);
-		g_assert (gda_data_model_set_value_at ((GdaDataModel *) proxy, proxy_col, proxy_row, 
-						       (GValue *) value, NULL));
-	}
-}
-
-/**
- * gda_data_proxy_clear_model_row_value
- */
-void
-gda_data_proxy_clear_model_row_value (GdaDataProxy *proxy, GdaDataModel *model, 
-				      gint proxy_row, gint extra_col)
-{
-	ExtraStore es;
-	const GValue *colval;
-
-	g_return_if_fail (GDA_IS_DATA_PROXY (proxy));
-	g_return_if_fail (proxy->priv);
-
-	es.model = model;
-	es.col = extra_col;
-	colval = g_hash_table_lookup (proxy->priv->extra_store, &es);
-	if (colval) {
-		gint proxy_col;
-		const GValue *value;
-
-		proxy_col = g_value_get_int ((GValue *) colval);
-		value = gda_data_model_get_value_at ((GdaDataModel *) proxy, 
-						     proxy_col + proxy->priv->model_nb_cols, proxy_row);
-		g_assert (gda_data_model_set_value_at ((GdaDataModel *) proxy, proxy_col, proxy_row, 
-						       (GValue *) value, NULL));
-	}
-}
-
-
-/**
- * gda_data_proxy_assign_model_col
- * @proxy: a #GdaDataProxy object
- * @model: a #GdaDataModel object
- * @proxy_col: a valid column number in @proxy
- * @model_col: a valid column number in @model
- *
- * Instructs @proxy about what to do if a call to gda_data_proxy_get_model_row_value(@proxy, @model, a_row, @model_col)
- * fails to return a non %NULL value. If that case appears, then @proxy will return the value stored in @proxy at
- * column @proxy_col and row 'a_row'.
- */
-void
-gda_data_proxy_assign_model_col (GdaDataProxy *proxy, GdaDataModel *model, gint proxy_col, gint model_col)
-{
-	ExtraStore *es;
-	GValue *value;
-
-	g_return_if_fail (GDA_IS_DATA_PROXY (proxy));
-	g_return_if_fail (proxy->priv);
-	if (proxy->priv->model_nb_cols > 0)
-		g_return_if_fail (proxy_col < proxy->priv->model_nb_cols);
-
-	es = g_new (ExtraStore, 1);
-	es->model = model;
-	es->col = model_col;
-
-	value = g_value_init (g_new0 (GValue, 1), G_TYPE_INT);
-	g_value_set_int (value, proxy_col);
-	g_hash_table_insert (proxy->priv->extra_store, es, value);
-
-	dump_extra_store (proxy);
-}
- 
-/**
- * gda_data_proxy_get_assigned_model_col
- */
-gint
-gda_data_proxy_get_assigned_model_col (GdaDataProxy *proxy, GdaDataModel *model, gint model_col)
-{
-	ExtraStore es;
-	const GValue *colval;
-
-	g_return_val_if_fail (GDA_IS_DATA_PROXY (proxy), -1);
-	g_return_val_if_fail (proxy->priv, -1);
-
-	es.model = model;
-	es.col = model_col;
-	colval = g_hash_table_lookup (proxy->priv->extra_store, &es);
-	if (colval)
-		return g_value_get_int ((GValue *) colval);
-	else
-		return -1;
-}
-
 /* 
  * GdaDataModel interface implementation
  */
@@ -2300,7 +2075,7 @@ gda_data_proxy_get_n_columns (GdaDataModel *model)
 
 
 typedef struct {
-	gchar        *name;
+	gchar *name;
 	GType  type;
 } ExtraColAttrs;
 
@@ -2497,12 +2272,17 @@ gda_data_proxy_set_value_at (GdaDataModel *model, gint col, gint proxy_row, cons
 {
 	gint row;
 	GdaDataProxy *proxy;
+	guint att;
 
 	g_return_val_if_fail (GDA_IS_DATA_PROXY (model), FALSE);
 	proxy = GDA_DATA_PROXY (model);
 	g_return_val_if_fail (proxy->priv, FALSE);
 	g_return_val_if_fail (proxy_row >= 0, FALSE);
 
+	att = gda_data_proxy_get_value_attributes (proxy, proxy_row, col);
+	if (att & GDA_VALUE_ATTR_NO_MODIF)
+		return FALSE;
+
 	row = proxy_row;
 	if ((row == 0) && proxy->priv->add_null_entry) {
 		g_warning ("Trying to set read-only NULL row");
@@ -2635,11 +2415,11 @@ gda_data_proxy_set_values (GdaDataModel *model, gint row, GList *values, GError
 		if (value && !gda_value_is_null (value)) {
 			GdaColumn *column;
 			column = gda_data_model_describe_column (model, col);
-			if (gda_column_get_gda_type (column) != G_VALUE_TYPE (value)) {
+			if (gda_column_get_g_type (column) != G_VALUE_TYPE (value)) {
 				g_set_error (error, 0, 0,
 					     _("Value type mismatch %s instead of %s"),
-					     gda_type_to_string (G_VALUE_TYPE (value)),
-					     gda_type_to_string (gda_column_get_gda_type (column)));
+					     gda_g_type_to_string (G_VALUE_TYPE (value)),
+					     gda_g_type_to_string (gda_column_get_g_type (column)));
 				err = TRUE;
 			}
 		}
