@@ -35,6 +35,7 @@ static void gda_dict_function_init (GdaDictFunction * srv);
 static void gda_dict_function_dispose (GObject   * object);
 static void gda_dict_function_finalize (GObject   * object);
 
+#if 0 /* This object does not have any properties. */
 static void gda_dict_function_set_property (GObject *object,
 					     guint param_id,
 					     const GValue *value,
@@ -43,6 +44,7 @@ static void gda_dict_function_get_property (GObject *object,
 					     guint param_id,
 					     GValue *value,
 					     GParamSpec *pspec);
+#endif
 
 #ifdef GDA_DEBUG
 static void gda_dict_function_dump (GdaDictFunction *func, guint offset);
@@ -56,13 +58,14 @@ static gboolean    gnome_db_function_load_from_xml (GdaXmlStorage *iface, xmlNod
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
 
-
+#if 0 /* This object does not have any properties. */
 /* properties */
 enum
 {
 	PROP_0,
 	PROP
 };
+#endif
 
 
 /* private structure */
@@ -133,6 +136,7 @@ gda_dict_function_class_init (GdaDictFunctionClass * class)
 	object_class->dispose = gda_dict_function_dispose;
 	object_class->finalize = gda_dict_function_finalize;
 
+        #if 0 /* This object does not have any properties. */
 	/* Properties */
 	object_class->set_property = gda_dict_function_set_property;
 	object_class->get_property = gda_dict_function_get_property;
@@ -143,6 +147,7 @@ gda_dict_function_class_init (GdaDictFunctionClass * class)
          */
 	g_object_class_install_property (object_class, PROP,
 					 g_param_spec_pointer ("prop", NULL, NULL, (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+        #endif
 
 	/* virtual functions */
 #ifdef GDA_DEBUG
@@ -225,7 +230,7 @@ gda_dict_function_finalize (GObject   * object)
 	parent_class->finalize (object);
 }
 
-
+#if 0 /* This object does not have any properties. */
 static void 
 gda_dict_function_set_property (GObject *object,
 			guint param_id,
@@ -264,6 +269,7 @@ gda_dict_function_get_property (GObject *object,
 		}	
 	}
 }
+#endif
 
 #ifdef GDA_DEBUG
 static void
@@ -334,34 +340,34 @@ gnome_db_function_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	func = GDA_DICT_FUNCTION (iface);
 
-	node = xmlNewNode (NULL, "gda_dict_function");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_dict_function");
 
 	str = gnome_db_function_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
-	xmlSetProp (node, "name", gda_object_get_name (GDA_OBJECT (func)));
-	xmlSetProp (node, "descr", gda_object_get_description (GDA_OBJECT (func)));
-	xmlSetProp (node, "owner", gda_object_get_owner (GDA_OBJECT (func)));
+	xmlSetProp(node, (xmlChar*)"name", (xmlChar*)gda_object_get_name (GDA_OBJECT (func)));
+	xmlSetProp(node, (xmlChar*)"descr", (xmlChar*)gda_object_get_description (GDA_OBJECT (func)));
+	xmlSetProp(node, (xmlChar*)"owner", (xmlChar*)gda_object_get_owner (GDA_OBJECT (func)));
 
 	/* return type */
 	if (func->priv->result_type) {
-		subnode = xmlNewChild (node, NULL, "gda_func_param", NULL);
+		subnode = xmlNewChild (node, NULL, (xmlChar*)"gda_func_param", NULL);
 		
 		str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (func->priv->result_type));
-		xmlSetProp (subnode, "type", str);
+		xmlSetProp(subnode, (xmlChar*)"type", (xmlChar*)str);
 		g_free (str);
-		xmlSetProp (subnode, "way", "out");
+		xmlSetProp(subnode, (xmlChar*)"way", (xmlChar*)"out");
 	}
 
 	/* argument types */
 	list = func->priv->arg_types;
 	while (list) {
-		subnode = xmlNewChild (node, NULL, "gda_func_param", NULL);
+		subnode = xmlNewChild (node, NULL, (xmlChar*)"gda_func_param", NULL);
 		if (list->data) {
 			str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (list->data));
-			xmlSetProp (subnode, "type", str);
+			xmlSetProp(subnode, (xmlChar*)"type", (xmlChar*)str);
 		}
-		xmlSetProp (subnode, "way", "in");
+		xmlSetProp(subnode, (xmlChar*)"way", (xmlChar*)"in");
 		list = g_slist_next (list);
 	}
 
@@ -384,7 +390,7 @@ gnome_db_function_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 
 	func = GDA_DICT_FUNCTION (iface);
 	dict = gda_object_get_dict (GDA_OBJECT (func));
-	if (strcmp (node->name, "gda_dict_function")) {
+	if (strcmp ((gchar*)node->name, "gda_dict_function")) {
 		g_set_error (error,
 			     GDA_DICT_FUNCTION_ERROR,
 			     GDA_DICT_FUNCTION_XML_LOAD_ERROR,
@@ -393,7 +399,7 @@ gnome_db_function_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 	}
 
 	/* function's attributes */
-	prop = xmlGetProp (node, "id");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"id");
 	if (prop) {
 		if ((*prop == 'P') && (*(prop+1)=='R')) {
 			pid = TRUE;
@@ -404,20 +410,20 @@ gnome_db_function_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "name");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"name");
 	if (prop) {
 		pname = TRUE;
 		gda_object_set_name (GDA_OBJECT (func), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "descr");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"descr");
 	if (prop) {
 		gda_object_set_description (GDA_OBJECT (func), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "owner");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"owner");
 	if (prop) {
 		gda_object_set_owner (GDA_OBJECT (func), prop);
 		g_free (prop);
@@ -426,9 +432,9 @@ gnome_db_function_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 	/* arguments and return type */
 	subnode = node->children;
 	while (subnode) {
-		if (!strcmp (subnode->name, "gda_func_param")) {
+		if (!strcmp ((gchar*)subnode->name, "gda_func_param")) {
 			GdaDictType *dt = NULL;
-			prop = xmlGetProp (subnode, "type");
+			prop = (gchar*)xmlGetProp(subnode, (xmlChar*)"type");
 			if (prop) {
 				dt = gda_dict_get_dict_type_by_xml_id (dict, prop);
 				if (!dt) {
@@ -438,7 +444,7 @@ gnome_db_function_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 				g_free (prop);
 			}
 			
-			prop = xmlGetProp (subnode, "way");
+			prop = (gchar*)xmlGetProp(subnode, (xmlChar*)"way");
 			if (prop) {
 				if (*prop == 'o') {
 					if (func->priv->result_type) {
