@@ -1,6 +1,6 @@
 /* gda-parameter.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,6 +20,7 @@
 
 #include <string.h>
 #include "gda-parameter.h"
+#include "gda-parameter-util.h"
 #include "gda-dict.h"
 #include "gda-dict-type.h"
 #include "gda-query.h"
@@ -1416,6 +1417,34 @@ gda_parameter_dump (GdaParameter *parameter, guint offset)
 }
 #endif
 
+/**
+ * gda_parameter_get_alphanum_name
+ * @param: a #GdaParameter object
+ *
+ * Get a new string containing a "clean" version of @param's name: chars which
+ * are not among [0-9A-Za-z] are replaced with '_'.
+ *
+ * Returns: a new string
+ */
+gchar *
+gda_parameter_get_alphanum_name (GdaParameter *param)
+{
+	gchar *ret, *ptr;
+	g_return_val_if_fail (GDA_IS_PARAMETER (param), NULL);
+
+	ptr = gda_object_get_name (GDA_OBJECT (param));
+	if (ptr)
+		ret = g_strdup (ptr);
+	else
+		ret = NULL;
+
+	for (ptr = ret; ptr && *ptr; ptr++)
+		if (! (((*ptr >= '0') || (*ptr <= '9')) ||
+		       ((*ptr >= 'A') || (*ptr <= 'Z')) ||
+		       ((*ptr >= 'a') || (*ptr <= 'z')))) 
+			*ptr = '_';
+	return ret;	
+}
 
 /* 
  * GdaReferer interface implementation
