@@ -1,6 +1,6 @@
 /* gda-query-condition.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -66,7 +66,8 @@ static gboolean    gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlN
 
 /* Renderer interface */
 static void            gda_query_condition_renderer_init      (GdaRendererIface *iface);
-static gchar          *gda_query_condition_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar          *gda_query_condition_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+							    GSList **out_params_used, guint options, GError **error);
 static gchar          *gda_query_condition_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Referer interface */
@@ -320,7 +321,7 @@ gda_query_condition_new_copy (GdaQueryCondition *orig, GHashTable *replacements)
 	while (list) {
 		GObject *ccond;
 
-		ccond = gda_query_condition_new_copy (GDA_QUERY_CONDITION (list->data), replacements);
+		ccond = G_OBJECT (gda_query_condition_new_copy (GDA_QUERY_CONDITION (list->data), replacements));
 		gda_query_condition_node_add_child (newcond, GDA_QUERY_CONDITION (ccond), NULL);
 		g_object_unref (ccond);
 		list = g_slist_next (list);
@@ -492,7 +493,6 @@ gda_query_condition_set_property (GObject *object,
 				  GParamSpec *pspec)
 {
 	GdaQueryCondition *condition;
-	gpointer ptr;
 	guint id;
 	gint i;
 	GdaDict *dict;
@@ -1373,32 +1373,32 @@ gda_query_condition_save_to_xml (GdaXmlStorage *iface, GError **error)
 
         cond = GDA_QUERY_CONDITION (iface);
 
-        node = xmlNewNode (NULL, "gda_query_cond");
+        node = xmlNewNode (NULL, (xmlChar*)"gda_query_cond");
 
         str = gda_xml_storage_get_xml_id (iface);
-        xmlSetProp (node, "id", str);
+        xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
         g_free (str);
 
-        xmlSetProp (node, "type", condition_type_to_str (cond->priv->type));
+        xmlSetProp(node, (xmlChar*)"type", (xmlChar*)condition_type_to_str (cond->priv->type));
 
 	base = gda_object_ref_get_ref_object (cond->priv->ops[GDA_QUERY_CONDITION_OP_LEFT]);
 	if (base) {
 		str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (base));
-		xmlSetProp (node, "l_op", str);
+		xmlSetProp(node, (xmlChar*)"l_op", (xmlChar*)str);
 		g_free (str);
 	}
 
 	base = gda_object_ref_get_ref_object (cond->priv->ops[GDA_QUERY_CONDITION_OP_RIGHT]);
 	if (base) {
 		str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (base));
-		xmlSetProp (node, "r_op", str);
+		xmlSetProp(node, (xmlChar*)"r_op", (xmlChar*)str);
 		g_free (str);
 	}
 
 	base = gda_object_ref_get_ref_object (cond->priv->ops[GDA_QUERY_CONDITION_OP_RIGHT2]);
 	if (base) {
 		str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (base));
-		xmlSetProp (node, "r_op2", str);
+		xmlSetProp(node, (xmlChar*)"r_op2", (xmlChar*)str);
 		g_free (str);
 	}
 
@@ -1432,7 +1432,7 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 
 	cond = GDA_QUERY_CONDITION (iface);
 
-	if (strcmp (node->name, "gda_query_cond")) {
+	if (strcmp ((gchar*)node->name, "gda_query_cond")) {
                 g_set_error (error,
                              GDA_QUERY_CONDITION_ERROR,
                              GDA_QUERY_CONDITION_XML_LOAD_ERROR,
@@ -1440,7 +1440,7 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
                 return FALSE;
         }
 
-	prop = xmlGetProp (node, "id");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"id");
         if (prop) {
                 gchar *ptr, *tok;
                 ptr = strtok_r (prop, ":", &tok);
@@ -1457,7 +1457,7 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
                 g_free (prop);
         }
 
-	prop = xmlGetProp (node, "type");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"type");
         if (prop) {
 		cond->priv->type = condition_str_to_type (prop);
 		if (cond->priv->type == GDA_QUERY_CONDITION_TYPE_UNKNOWN) {
@@ -1470,7 +1470,7 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
                 g_free (prop);
         }
 
-	prop = xmlGetProp (node, "l_op");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"l_op");
 	if (prop) {
 		gda_object_ref_set_ref_name (cond->priv->ops[GDA_QUERY_CONDITION_OP_LEFT], GDA_TYPE_QUERY_FIELD,
 					  REFERENCE_BY_XML_ID, prop);
@@ -1478,14 +1478,14 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 	}
 
 
-	prop = xmlGetProp (node, "r_op");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"r_op");
 	if (prop) {
 		gda_object_ref_set_ref_name (cond->priv->ops[GDA_QUERY_CONDITION_OP_RIGHT], GDA_TYPE_QUERY_FIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "r_op2");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"r_op2");
 	if (prop) {
 		gda_object_ref_set_ref_name (cond->priv->ops[GDA_QUERY_CONDITION_OP_RIGHT2], GDA_TYPE_QUERY_FIELD,
 					  REFERENCE_BY_XML_ID, prop);
@@ -1495,7 +1495,7 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 	/* children nodes */
 	children = node->children;
 	while (children) {
-		if (!strcmp (children->name, "gda_query_cond")) {
+		if (!strcmp ((gchar*)children->name, "gda_query_cond")) {
 			GdaQueryCondition *scond;
 
 			scond = gda_query_condition_new (cond->priv->query, GDA_QUERY_CONDITION_NODE_AND);
@@ -1527,7 +1527,8 @@ gda_query_condition_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
  */
 
 static gchar *
-gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
+				   GSList **out_params_used, guint options, GError **error)
 {
         gchar *retval = NULL, *str;
 	GString *string;
@@ -1697,7 +1698,7 @@ gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context
 						g_string_append (string, "(");
 
 					str = gda_renderer_render_as_sql (GDA_RENDERER (list->data), context, 
-									 options, error);
+									  out_params_used, options, error);
 					if (!str) {
 						g_string_free (string, TRUE);
 						return NULL;
@@ -1714,7 +1715,7 @@ gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context
 			else { /* type = NOT */
 				g_string_append_printf (string, "%s", link);
 				str = gda_renderer_render_as_sql (GDA_RENDERER (cond->priv->cond_children->data), 
-								 context, options, error);
+								  context, out_params_used, options, error);
 				if (!str) {
 					g_string_free (string, TRUE);
 					return NULL;
@@ -1727,7 +1728,7 @@ gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context
 		}
 		else {
 			str = gda_renderer_render_as_sql (GDA_RENDERER (ops[GDA_QUERY_CONDITION_OP_LEFT]), context, 
-							 options, error);
+							  out_params_used, options, error);
 			if (!str) {
 				g_string_free (string, TRUE);
 				return NULL;
@@ -1736,7 +1737,7 @@ gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context
 			g_free (str);
 			g_string_append_printf (string, "%s", link);
 			str = gda_renderer_render_as_sql (GDA_RENDERER (ops[GDA_QUERY_CONDITION_OP_RIGHT]), context, 
-							 options, error);
+							  out_params_used, options, error);
 			if (!str) {
 				g_string_free (string, TRUE);
 				return NULL;
@@ -1748,7 +1749,7 @@ gda_query_condition_render_as_sql (GdaRenderer *iface, GdaParameterList *context
 
 	if (cond->priv->type == GDA_QUERY_CONDITION_LEAF_BETWEEN) {
 		str = gda_renderer_render_as_sql (GDA_RENDERER (ops[GDA_QUERY_CONDITION_OP_RIGHT2]), context, 
-						 options, error);
+						  out_params_used, options, error);
 		if (!str) {
 			g_string_free (string, TRUE);
 			return NULL;
@@ -1771,7 +1772,7 @@ gda_query_condition_render_as_str (GdaRenderer *iface, GdaParameterList *context
         g_return_val_if_fail (iface && GDA_IS_QUERY_CONDITION (iface), NULL);
         g_return_val_if_fail (GDA_QUERY_CONDITION (iface)->priv, NULL);
 
-        str = gda_query_condition_render_as_sql (iface, context, 0, NULL);
+        str = gda_query_condition_render_as_sql (iface, context, NULL, 0, NULL);
         if (!str)
                 str = g_strdup ("???");
         return str;
