@@ -1,6 +1,6 @@
 /* gda-query-field-agg.c
  *
- * Copyright (C) 2005 Vivien Malerba
+ * Copyright (C) 2005 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -62,7 +62,8 @@ static GdaDictType *gda_query_field_agg_get_data_type   (GdaEntityField *iface);
 
 /* Renderer interface */
 static void         gda_query_field_agg_renderer_init   (GdaRendererIface *iface);
-static gchar       *gda_query_field_agg_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar       *gda_query_field_agg_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+							 GSList **out_params_used, guint options, GError **error);
 static gchar       *gda_query_field_agg_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Referer interface */
@@ -217,12 +218,14 @@ gda_query_field_agg_class_init (GdaQueryFieldAggClass * class)
 	object_class->set_property = gda_query_field_agg_set_property;
 	object_class->get_property = gda_query_field_agg_get_property;
 	g_object_class_install_property (object_class, PROP_QUERY,
-					 g_param_spec_pointer ("query", "Query to which the field belongs", NULL, 
+					 g_param_spec_object ("query", "Query to which the field belongs", NULL, 
+                                                               GDA_TYPE_QUERY,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE |
 								G_PARAM_CONSTRUCT_ONLY)));
 
 	g_object_class_install_property (object_class, PROP_AGG_OBJ,
-					 g_param_spec_pointer ("aggregate", "A pointer to a GdaDictAggregate", NULL, 
+					 g_param_spec_object ("aggregate", "A pointer to a GdaDictAggregate", NULL,
+                                                               GDA_TYPE_DICT_AGGREGATE, 
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_AGG_NAME,
 					 g_param_spec_string ("aggregate_name", "Name of the aggregate to represent", NULL, NULL,
@@ -260,7 +263,7 @@ gda_query_field_agg_init (GdaQueryFieldAgg *gda_query_field_agg)
  *
  * Returns: the new object
  */
-GObject*
+GdaQueryField*
 gda_query_field_agg_new (GdaQuery *query, const gchar *agg_name)
 {
 	GObject *obj;
@@ -271,7 +274,7 @@ gda_query_field_agg_new (GdaQuery *query, const gchar *agg_name)
 	obj = g_object_new (GDA_TYPE_QUERY_FIELD_AGG, "dict", gda_object_get_dict (GDA_OBJECT (query)), 
 			    "query", query, "aggregate_name", agg_name, NULL);
 
-	return obj;
+	return (GdaQueryField*) obj;
 }
 
 static void 
@@ -339,15 +342,14 @@ gda_query_field_agg_set_property (GObject *object,
 			GParamSpec *pspec)
 {
 	GdaQueryFieldAgg *fagg;
-	gpointer ptr;
 	guint id;
 	const gchar *str;
 
 	fagg = GDA_QUERY_FIELD_AGG (object);
 	if (fagg->priv) {
 		switch (param_id) {
-		case PROP_QUERY:
-			ptr = g_value_get_pointer (value);
+		case PROP_QUERY: {
+			GdaQuery* ptr = GDA_QUERY (g_value_get_object (value));
 			g_return_if_fail (ptr && GDA_IS_QUERY (ptr));
 
 			if (fagg->priv->query) {
@@ -367,11 +369,13 @@ gda_query_field_agg_set_property (GObject *object,
 			g_object_get (G_OBJECT (ptr), "field_serial", &id, NULL);
 			gda_query_object_set_int_id (GDA_QUERY_OBJECT (fagg), id);
 			break;
-		case PROP_AGG_OBJ:
-			ptr = g_value_get_pointer (value);
+                }
+		case PROP_AGG_OBJ: {
+			GdaDictAggregate* ptr = GDA_DICT_AGGREGATE(g_value_get_object (value));
 			g_return_if_fail (GDA_IS_DICT_AGGREGATE (ptr));
 			gda_object_ref_set_ref_object (fagg->priv->agg_ref, GDA_OBJECT (ptr));
 			break;
+                }
 		case PROP_AGG_NAME:
 			str = g_value_get_string (value);
 			gda_object_ref_set_ref_name (fagg->priv->agg_ref, GDA_TYPE_DICT_AGGREGATE, 
@@ -398,10 +402,10 @@ gda_query_field_agg_get_property (GObject *object,
 	if (fagg->priv) {
 		switch (param_id) {
 		case PROP_QUERY:
-			g_value_set_pointer (value, fagg->priv->query);
+			g_value_set_object (value, G_OBJECT (fagg->priv->query));
 			break;
 		case PROP_AGG_OBJ:
-			g_value_set_pointer (value, gda_object_ref_get_ref_object (fagg->priv->agg_ref));
+			g_value_set_object (value, G_OBJECT (gda_object_ref_get_ref_object (fagg->priv->agg_ref)));
 			break;
 		case PROP_AGG_NAME:
 		case PROP_AGG_ID:
@@ -536,7 +540,7 @@ gda_query_field_agg_set_arg (GdaQueryFieldAgg *agg, GdaQueryField *arg)
 		GdaDict *dict;
 		GdaConnection *cnc;
 		GdaDictAggregate *sagg = GDA_DICT_AGGREGATE (gda_object_ref_get_ref_object (agg->priv->agg_ref));
-		GdaDictType *argtype = gda_dict_aggregate_get_arg_type (sagg);
+		GdaDictType *argtype = gda_dict_aggregate_get_arg_dict_type (sagg);
 
 		dict = gda_object_get_dict (GDA_OBJECT (agg));
 		cnc = gda_dict_get_connection (dict);
@@ -551,8 +555,8 @@ gda_query_field_agg_set_arg (GdaQueryFieldAgg *agg, GdaQueryField *arg)
 			}
 			else {
 				/* GType compatibility test */
-				if (gda_dict_type_get_gda_type (gda_query_field_get_dict_type (GDA_QUERY_FIELD (arg))) !=
-				    gda_dict_type_get_gda_type (argtype))
+				if (gda_dict_type_get_g_type (gda_query_field_get_dict_type (GDA_QUERY_FIELD (arg))) !=
+				    gda_dict_type_get_g_type (argtype))
 					arg_ok = FALSE;
 			}
 		}
@@ -591,7 +595,7 @@ gda_query_field_agg_set_arg (GdaQueryFieldAgg *agg, GdaQueryField *arg)
  * Returns: the #GnomeDbQField argument
  */
 GdaQueryField *
-gda_query_field_agg_get_args (GdaQueryFieldAgg *agg)
+gda_query_field_agg_get_arg (GdaQueryFieldAgg *agg)
 {
 	g_return_val_if_fail (agg && GDA_IS_QUERY_FIELD_AGG (agg), NULL);
 	g_return_val_if_fail (agg->priv, NULL);
@@ -657,7 +661,7 @@ gda_query_field_agg_get_data_type (GdaEntityField *iface)
 	if (gda_query_field_agg_activate (GDA_REFERER (iface))) {
 		GdaDictAggregate *agg;
 		agg = GDA_DICT_AGGREGATE (gda_object_ref_get_ref_object (GDA_QUERY_FIELD_AGG (iface)->priv->agg_ref));
-		return gda_dict_aggregate_get_ret_type (agg);
+		return gda_dict_aggregate_get_ret_dict_type (agg);
 	}
 
 	return NULL;
@@ -679,15 +683,15 @@ gda_query_field_agg_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	agg = GDA_QUERY_FIELD_AGG (iface);
 
-	node = xmlNewNode (NULL, "gda_query_fagg");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_query_fagg");
 	
 	str = gda_xml_storage_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
 
-	xmlSetProp (node, "name", gda_object_get_name (GDA_OBJECT (agg)));
+	xmlSetProp(node, (xmlChar*)"name", (xmlChar*)gda_object_get_name (GDA_OBJECT (agg)));
 	if (gda_object_get_description (GDA_OBJECT (agg)) && *gda_object_get_description (GDA_OBJECT (agg)))
-		xmlSetProp (node, "descr", gda_object_get_description (GDA_OBJECT (agg)));
+		xmlSetProp(node, (xmlChar*)"descr", (xmlChar*)gda_object_get_description (GDA_OBJECT (agg)));
 
 	obj = NULL;
 	if (gda_object_ref_activate (agg->priv->agg_ref))
@@ -696,31 +700,31 @@ gda_query_field_agg_save_to_xml (GdaXmlStorage *iface, GError **error)
 	if (obj) {
 		gchar *xmlid;
 		xmlid = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (obj));
-		xmlSetProp (node, "agg", xmlid);
+		xmlSetProp(node, (xmlChar*)"agg", (xmlChar*)xmlid);
 	}
 	else {
 		const gchar *cstr;
 
 		cstr = gda_object_ref_get_ref_name (agg->priv->agg_ref, NULL, NULL);
 		if (cstr)
-			xmlSetProp (node, "agg_name", cstr);
+			xmlSetProp(node, (xmlChar*)"agg_name", (xmlChar*)cstr);
 	}
 
 	if (! gda_query_field_is_visible (GDA_QUERY_FIELD (agg)))
-		xmlSetProp (node, "is_visible",  "f");
+		xmlSetProp(node, (xmlChar*)"is_visible",  (xmlChar*)"f");
 	if (gda_query_field_is_internal (GDA_QUERY_FIELD (agg)))
-		xmlSetProp (node, "is_internal", "t");
+		xmlSetProp(node, (xmlChar*)"is_internal", (xmlChar*)"t");
 
 	str = (gchar *) gda_query_field_get_alias (GDA_QUERY_FIELD (agg));
 	if (str && *str) 
-		xmlSetProp (node, "alias", str);
+		xmlSetProp(node, (xmlChar*)"alias", (xmlChar*)str);
 
 	/* aggregate's argument */
 	if (agg->priv->arg) {
 		xmlNodePtr argnode;
 		
-		argnode = xmlNewChild (node, NULL, "gda_query_field_ref", NULL);
-		xmlSetProp (argnode, "object", gda_object_ref_get_ref_name (agg->priv->arg, NULL, NULL));
+		argnode = xmlNewChild (node, NULL, (xmlChar*)"gda_query_field_ref", NULL);
+		xmlSetProp(argnode, (xmlChar*)"object", (xmlChar*)gda_object_ref_get_ref_name (agg->priv->arg, NULL, NULL));
 	}
 
 	return node;
@@ -738,7 +742,7 @@ gda_query_field_agg_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 	g_return_val_if_fail (node, FALSE);
 
 	agg = GDA_QUERY_FIELD_AGG (iface);
-	if (strcmp (node->name, "gda_query_fagg")) {
+	if (strcmp ((gchar*)node->name, "gda_query_fagg")) {
 		g_set_error (error,
 			     GDA_QUERY_FIELD_AGG_ERROR,
 			     GDA_QUERY_FIELD_AGG_XML_LOAD_ERROR,
@@ -746,7 +750,7 @@ gda_query_field_agg_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		return FALSE;
 	}
 
-	prop = xmlGetProp (node, "id");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"id");
 	if (prop) {
 		gchar *ptr, *tok;
 		ptr = strtok_r (prop, ":", &tok);
@@ -762,26 +766,26 @@ gda_query_field_agg_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "name");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"name");
 	if (prop) {
 		gda_object_set_name (GDA_OBJECT (agg), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "descr");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"descr");
 	if (prop) {
 		gda_object_set_description (GDA_OBJECT (agg), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "agg");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"agg");
 	if (prop) {
 		aggref = TRUE;
 		gda_object_ref_set_ref_name (agg->priv->agg_ref, GDA_TYPE_DICT_AGGREGATE, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 	else {
-		prop = xmlGetProp (node, "agg_name");
+		prop = (gchar*)xmlGetProp(node, (xmlChar*)"agg_name");
 		if (prop) {
 			aggref = TRUE;
 			gda_object_ref_set_ref_name (agg->priv->agg_ref, GDA_TYPE_DICT_AGGREGATE, REFERENCE_BY_NAME, prop);
@@ -789,19 +793,19 @@ gda_query_field_agg_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		}
 	}
 
-	prop = xmlGetProp (node, "is_visible");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_visible");
 	if (prop) {
 		gda_query_field_set_visible (GDA_QUERY_FIELD (agg), (*prop == 't') ? TRUE : FALSE);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "is_internal");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_internal");
 	if (prop) {
 		gda_query_field_set_internal (GDA_QUERY_FIELD (agg), (*prop == 't') ? TRUE : FALSE);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "alias");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"alias");
 	if (prop) {
 		gda_query_field_set_alias (GDA_QUERY_FIELD (agg), prop);
 		g_free (prop);
@@ -813,9 +817,9 @@ gda_query_field_agg_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		xmlNodePtr argnode = node->children;
 		dict = gda_object_get_dict (GDA_OBJECT (agg));
 		while (argnode) {
-			if (!strcmp (argnode->name, "gda_query_field_ref")) {
+			if (!strcmp ((gchar*)argnode->name, "gda_query_field_ref")) {
 				if (! agg->priv->arg) {
-					prop = xmlGetProp (argnode, "object");
+					prop = (gchar*)xmlGetProp(argnode, (xmlChar*)"object");
 					if (prop) {
 						GdaObjectRef *ref;
 						
@@ -858,7 +862,8 @@ gda_query_field_agg_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
  */
 
 static gchar *
-gda_query_field_agg_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_query_field_agg_render_as_sql (GdaRenderer *iface, GdaParameterList *context, GSList **out_params_used, 
+				   guint options, GError **error)
 {
 	gchar *str = NULL;
 	GdaObject *base;
@@ -882,8 +887,8 @@ gda_query_field_agg_render_as_sql (GdaRenderer *iface, GdaParameterList *context
 
 			argbase = gda_object_ref_get_ref_object (agg->priv->arg);
 			if (argbase) {
-				argstr = gda_renderer_render_as_sql (GDA_RENDERER (argbase), context, 
-									  options, error);
+				argstr = gda_renderer_render_as_sql (GDA_RENDERER (argbase), context, out_params_used,
+								     options, error);
 				if (argstr) {
 					g_string_append (string, argstr);
 					g_free (argstr);
