@@ -62,7 +62,8 @@ static GdaDictType *gda_query_field_field_get_data_type   (GdaEntityField *iface
 
 /* Renderer interface */
 static void         gda_query_field_field_renderer_init   (GdaRendererIface *iface);
-static gchar       *gda_query_field_field_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar       *gda_query_field_field_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+							   GSList **out_params_used, guint options, GError **error);
 static gchar       *gda_query_field_field_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Referer interface */
@@ -260,7 +261,7 @@ gda_query_field_field_class_init (GdaQueryFieldFieldClass * class)
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_FIELD_NAME,
 					 g_param_spec_string ("field_name", "Name of an entity field", NULL, NULL,
-							      G_PARAM_WRITABLE));
+							      G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_FIELD_ID,
 					 g_param_spec_string ("field_id", "XML ID of an entity field", NULL, NULL,
 							      G_PARAM_WRITABLE));
@@ -574,9 +575,11 @@ gda_query_field_field_get_property (GObject *object,
 		case PROP_FIELD_OBJ:
 			g_value_set_object (value, G_OBJECT (gda_object_ref_get_ref_object (ffield->priv->field_ref)));
 			break;
+		case PROP_FIELD_NAME:
+			g_value_set_string (value, gda_object_ref_get_ref_name (ffield->priv->field_ref, NULL, NULL));
+			break;
 		case PROP_TARGET_NAME:
 		case PROP_TARGET_ID:
-		case PROP_FIELD_NAME:
 		case PROP_FIELD_ID:
 			/* NO READ */
 			g_assert_not_reached ();
@@ -853,15 +856,15 @@ gda_query_field_field_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	field = GDA_QUERY_FIELD_FIELD (iface);
 
-	node = xmlNewNode (NULL, "gda_query_ffield");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_query_ffield");
 	
 	str = gda_xml_storage_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
 
-	xmlSetProp (node, "name", gda_object_get_name (GDA_OBJECT (field)));
+	xmlSetProp(node, (xmlChar*)"name", (xmlChar*)gda_object_get_name (GDA_OBJECT (field)));
 	if (gda_object_get_description (GDA_OBJECT (field)) && *gda_object_get_description (GDA_OBJECT (field)))
-		xmlSetProp (node, "descr", gda_object_get_description (GDA_OBJECT (field)));
+		xmlSetProp(node, (xmlChar*)"descr", (xmlChar*)gda_object_get_description (GDA_OBJECT (field)));
 	
 	obj = NULL;
 	if (gda_object_ref_activate (field->priv->target_ref))
@@ -870,14 +873,14 @@ gda_query_field_field_save_to_xml (GdaXmlStorage *iface, GError **error)
 	if (obj) {
 		gchar *xmlid;
 		xmlid = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (obj));
-		xmlSetProp (node, "target", xmlid);
+		xmlSetProp(node, (xmlChar*)"target", (xmlChar*)xmlid);
 	}
 	else {
 		const gchar *cstr;
 
 		cstr = gda_object_ref_get_ref_name (field->priv->target_ref, NULL, NULL);
 		if (cstr)
-			xmlSetProp (node, "target_name", cstr);
+			xmlSetProp(node, (xmlChar*)"target_name", (xmlChar*)cstr);
 	}
 
 	obj = NULL;
@@ -886,30 +889,30 @@ gda_query_field_field_save_to_xml (GdaXmlStorage *iface, GError **error)
 	if (obj) {
 		gchar *xmlid;
 		xmlid = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (obj));
-		xmlSetProp (node, "object", xmlid);
+		xmlSetProp(node, (xmlChar*)"object", (xmlChar*)xmlid);
 	}
 	else {
 		const gchar *tmpstr;
 
 		tmpstr = gda_object_ref_get_ref_name (field->priv->field_ref, NULL, NULL);
 		if (tmpstr)
-			xmlSetProp (node, "object_name", tmpstr);
+			xmlSetProp(node, (xmlChar*)"object_name", (xmlChar*)tmpstr);
 	}
 
 	if (! gda_query_field_is_visible (GDA_QUERY_FIELD (field)))
-		xmlSetProp (node, "is_visible",  "f");
+		xmlSetProp(node, (xmlChar*)"is_visible",  (xmlChar*)"f");
 	if (gda_query_field_is_internal (GDA_QUERY_FIELD (field)))
-		xmlSetProp (node, "is_internal", "t");
+		xmlSetProp(node, (xmlChar*)"is_internal", (xmlChar*)"t");
 
 	if (field->priv->value_prov_ref)
-		xmlSetProp (node, "value_prov", gda_object_ref_get_ref_name (field->priv->value_prov_ref, NULL, NULL));
+		xmlSetProp(node, (xmlChar*)"value_prov", (xmlChar*)gda_object_ref_get_ref_name (field->priv->value_prov_ref, NULL, NULL));
 
 	str = (gchar *) gda_query_field_get_alias (GDA_QUERY_FIELD (field));
 	if (str && *str) 
-		xmlSetProp (node, "alias", str);
+		xmlSetProp(node, (xmlChar*)"alias", (xmlChar*)str);
 
 	if (field->priv->plugin)
-		xmlSetProp (node, "plugin", field->priv->plugin);
+		xmlSetProp(node, (xmlChar*)"plugin", (xmlChar*)field->priv->plugin);
 
 	return node;
 }
@@ -926,7 +929,7 @@ gda_query_field_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 	g_return_val_if_fail (node, FALSE);
 
 	field = GDA_QUERY_FIELD_FIELD (iface);
-	if (strcmp (node->name, "gda_query_ffield")) {
+	if (strcmp ((gchar*)node->name, "gda_query_ffield")) {
 		g_set_error (error,
 			     GDA_QUERY_FIELD_FIELD_ERROR,
 			     GDA_QUERY_FIELD_FIELD_XML_LOAD_ERROR,
@@ -934,7 +937,7 @@ gda_query_field_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		return FALSE;
 	}
 
-	prop = xmlGetProp (node, "id");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"id");
 	if (prop) {
 		gchar *ptr, *tok;
 		ptr = strtok_r (prop, ":", &tok);
@@ -950,26 +953,26 @@ gda_query_field_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "name");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"name");
 	if (prop) {
 		gda_object_set_name (GDA_OBJECT (field), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "descr");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"descr");
 	if (prop) {
 		gda_object_set_description (GDA_OBJECT (field), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "target");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"target");
 	if (prop) {
 		target = TRUE;
 		gda_object_ref_set_ref_name (field->priv->target_ref, GDA_TYPE_QUERY_TARGET, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 	else {
-		prop = xmlGetProp (node, "target_name");
+		prop = (gchar*)xmlGetProp(node, (xmlChar*)"target_name");
 		if (prop) {
 			target = TRUE;
 			gda_object_ref_set_ref_name (field->priv->target_ref, GDA_TYPE_QUERY_TARGET, REFERENCE_BY_NAME, prop);
@@ -977,14 +980,14 @@ gda_query_field_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		}
 	}
 
-	prop = xmlGetProp (node, "object");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"object");
 	if (prop) {
 		target = TRUE;
 		gda_object_ref_set_ref_name (field->priv->field_ref, GDA_TYPE_ENTITY_FIELD, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 	else {
-		prop = xmlGetProp (node, "object_name");
+		prop = (gchar*)xmlGetProp(node, (xmlChar*)"object_name");
 		if (prop) {
 			target = TRUE;
 			gda_object_ref_set_ref_name (field->priv->field_ref, GDA_TYPE_ENTITY_FIELD, REFERENCE_BY_NAME, prop);
@@ -992,31 +995,31 @@ gda_query_field_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		}
 	}
 
-	prop = xmlGetProp (node, "is_visible");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_visible");
 	if (prop) {
 		gda_query_field_set_visible (GDA_QUERY_FIELD (field), (*prop == 't') ? TRUE : FALSE);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "is_internal");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_internal");
 	if (prop) {
 		gda_query_field_set_internal (GDA_QUERY_FIELD (field), (*prop == 't') ? TRUE : FALSE);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "value_prov");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"value_prov");
 	if (prop) {
 		g_object_set (G_OBJECT (iface), "value_provider_xml_id", prop, NULL);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "alias");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"alias");
 	if (prop) {
 		gda_query_field_set_alias (GDA_QUERY_FIELD (field), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "plugin");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"plugin");
 	if (prop) 
 		field->priv->plugin = prop;
 
@@ -1037,7 +1040,8 @@ gda_query_field_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
  */
 
 static gchar *
-gda_query_field_field_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_query_field_field_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
+				     GSList **out_params_used, guint options, GError **error)
 {
 	GdaQueryFieldField *field;
 	GdaObject *fobj;
