@@ -1,6 +1,6 @@
 /* gda-query-field-value.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,6 +29,7 @@
 #include "gda-query.h"
 #include "gda-data-handler.h"
 #include "gda-parameter.h"
+#include "gda-parameter-util.h"
 #include "gda-object-ref.h"
 #include "gda-parameter-list.h"
 #include "gda-connection.h"
@@ -44,13 +45,13 @@ static void gda_query_field_value_dispose (GObject *object);
 static void gda_query_field_value_finalize (GObject *object);
 
 static void gda_query_field_value_set_property (GObject *object,
-				    guint param_id,
-				    const GValue *value,
-				    GParamSpec *pspec);
+						guint param_id,
+						const GValue *value,
+						GParamSpec *pspec);
 static void gda_query_field_value_get_property (GObject *object,
-				    guint param_id,
-				    GValue *value,
-				    GParamSpec *pspec);
+						guint param_id,
+						GValue *value,
+						GParamSpec *pspec);
 
 /* XML storage interface */
 static void        gda_query_field_value_xml_storage_init (GdaXmlStorageIface *iface);
@@ -65,7 +66,8 @@ static GdaDictType       *gda_query_field_value_get_data_type   (GdaEntityField
 
 /* Renderer interface */
 static void            gda_query_field_value_renderer_init      (GdaRendererIface *iface);
-static gchar          *gda_query_field_value_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar          *gda_query_field_value_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+							      GSList **out_params_used, guint options, GError **error);
 static gchar          *gda_query_field_value_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Referer interface */
@@ -85,7 +87,7 @@ static void destroyed_restrict_cb (GdaObject *obj, GdaQueryFieldValue *field);
 static GSList   *gda_query_field_value_get_params (GdaQueryField *qfield);
 
 static gboolean gda_query_field_value_render_find_value (GdaQueryFieldValue *field, GdaParameterList *context,
-					       const GValue **value_found, GdaParameter **param_source);
+							 const GValue **value_found, GdaParameter **param_source);
 
 #ifdef GDA_DEBUG
 static void gda_query_field_value_dump (GdaQueryFieldValue *field, guint offset);
@@ -900,6 +902,39 @@ gda_query_field_value_get_dict_type (GdaQueryFieldValue *field)
 	return field->priv->dict_type;
 }
 
+/**
+ * gda_query_field_value_get_parameter_index
+ * @field: a #GdaQueryFieldValue object
+ *
+ * Get the index of @field in the query it belongs, among all the parameters.
+ *
+ * Returns: the index (starting at 1), or -1 if @field is not a parameter field.
+ */
+gint
+gda_query_field_value_get_parameter_index (GdaQueryFieldValue *field)
+{
+	GdaQuery *query;
+	GSList *fields, *list;
+	gint index = -1;
+
+	g_return_val_if_fail (GDA_IS_QUERY_FIELD_VALUE (field), -1);
+	g_return_val_if_fail (field->priv, -1);
+
+	query = GDA_QUERY (gda_entity_field_get_entity (GDA_ENTITY_FIELD (field)));
+	g_object_get (G_OBJECT (query), "really_all_fields", &fields, NULL);
+	for (list = fields; list; list = list->next) {
+		if (GDA_IS_QUERY_FIELD_VALUE (list->data) && 
+		    gda_query_field_value_is_parameter (GDA_QUERY_FIELD_VALUE (list->data)))
+			index++;
+		if (list->data == (gpointer) field)
+			break;
+	}
+		
+	if (index >= 0) index++;
+	return index;
+}
+
+
 #ifdef GDA_DEBUG
 static void
 gda_query_field_value_dump (GdaQueryFieldValue *field, guint offset)
@@ -1010,32 +1045,32 @@ gda_query_field_value_save_to_xml (GdaXmlStorage *iface, GError **error)
 	field = GDA_QUERY_FIELD_VALUE (iface);
 	dict = gda_object_get_dict (GDA_OBJECT (field));
 
-	node = xmlNewNode (NULL, "gda_query_fval");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_query_fval");
 	
 	str = gda_xml_storage_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
 
-	xmlSetProp (node, "name", gda_object_get_name (GDA_OBJECT (field)));
+	xmlSetProp(node, (xmlChar*)"name", (xmlChar*)gda_object_get_name (GDA_OBJECT (field)));
 	if (gda_object_get_description (GDA_OBJECT (field)) && *gda_object_get_description (GDA_OBJECT (field)))
-		xmlSetProp (node, "descr", gda_object_get_description (GDA_OBJECT (field)));
+		xmlSetProp(node, (xmlChar*)"descr", (xmlChar*)gda_object_get_description (GDA_OBJECT (field)));
 	if (! gda_query_field_is_visible (GDA_QUERY_FIELD (field)))
-		xmlSetProp (node, "is_visible",  "f");
+		xmlSetProp(node, (xmlChar*)"is_visible",  (xmlChar*)"f");
 	if (gda_query_field_is_internal (GDA_QUERY_FIELD (field)))
-		xmlSetProp (node, "is_internal", "t");
+		xmlSetProp(node, (xmlChar*)"is_internal", (xmlChar*)"t");
 
-	xmlSetProp (node, "is_param", field->priv->is_parameter ? "t" : "f");
-	xmlSetProp (node, "g_type",  gda_g_type_to_string (field->priv->g_type));
+	xmlSetProp(node, (xmlChar*)"is_param", (xmlChar*)(field->priv->is_parameter ? "t" : "f"));
+	xmlSetProp(node, (xmlChar*)"g_type",  (xmlChar*)gda_g_type_to_string (field->priv->g_type));
 	if (field->priv->dict_type) {
 		str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (field->priv->dict_type));
-		xmlSetProp (node, "dict_type",  str);
+		xmlSetProp(node, (xmlChar*)"dict_type", (xmlChar*)str);
 		g_free (str);
 	}
 
 	dh = gda_dict_get_default_handler (dict, field->priv->g_type);
 	if (field->priv->value && (field->priv->g_type != GDA_TYPE_NULL)) {
 		str = gda_data_handler_get_str_from_value (dh, field->priv->value);
-		xmlSetProp (node, "value", str);
+		xmlSetProp(node, (xmlChar*)"value", (xmlChar*)str);
 		g_free (str);
 	}
 	if (field->priv->default_value) {
@@ -1043,13 +1078,13 @@ gda_query_field_value_save_to_xml (GdaXmlStorage *iface, GError **error)
 		GType vtype;
 		
 		str = gda_data_handler_get_str_from_value (dhd, field->priv->default_value);
-		xmlSetProp (node, "default", str);
+		xmlSetProp(node, (xmlChar*)"default", (xmlChar*)str);
 		g_free (str);
 		vtype = G_VALUE_TYPE (field->priv->default_value);
-		xmlSetProp (node, "default_g_type", gda_g_type_to_string (vtype));
+		xmlSetProp(node, (xmlChar*)"default_g_type", (xmlChar*)gda_g_type_to_string (vtype));
 	}
 
-	xmlSetProp (node, "nullok", field->priv->is_null_allowed ? "t" : "f");
+	xmlSetProp(node, (xmlChar*)"nullok", (xmlChar*)(field->priv->is_null_allowed ? "t" : "f"));
 
 	if (field->priv->restrict_model) {
 		GSList *psources = (GSList *) gda_query_get_param_sources (field->priv->query);
@@ -1070,17 +1105,17 @@ gda_query_field_value_save_to_xml (GdaXmlStorage *iface, GError **error)
 			}
 		}
 		if (str) {
-			xmlSetProp (node, "restrict", str);
+			xmlSetProp(node, (xmlChar*)"restrict", (xmlChar*)str);
 			g_free (str);
 		}
 	}
 
 	cstr = gda_query_field_get_alias (GDA_QUERY_FIELD (field));
 	if (cstr && *cstr) 
-		xmlSetProp (node, "alias", cstr);
+		xmlSetProp(node, (xmlChar*)"alias", (xmlChar*)cstr);
 	
 	if (field->priv->plugin)
-		xmlSetProp (node, "plugin", field->priv->plugin);
+		xmlSetProp(node, (xmlChar*)"plugin", (xmlChar*)field->priv->plugin);
 
 	return node;
 }
@@ -1100,7 +1135,7 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 
 	field = GDA_QUERY_FIELD_VALUE (iface);
 	dict = gda_object_get_dict (GDA_OBJECT (field));
-	if (strcmp (node->name, "gda_query_fval")) {
+	if (strcmp ((gchar*)node->name, "gda_query_fval")) {
 		g_set_error (error,
 			     GDA_QUERY_FIELD_VALUE_ERROR,
 			     GDA_QUERY_FIELD_VALUE_XML_LOAD_ERROR,
@@ -1108,7 +1143,7 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		return FALSE;
 	}
 
-	prop = xmlGetProp (node, "id");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"id");
 	if (prop) {
 		gchar *ptr, *tok;
 		ptr = strtok_r (prop, ":", &tok);
@@ -1124,31 +1159,31 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "name");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"name");
 	if (prop) {
 		gda_object_set_name (GDA_OBJECT (field), prop);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "descr");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"descr");
 	if (prop) {
 		gda_object_set_description (GDA_OBJECT (field), prop);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "is_visible");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_visible");
 	if (prop) {
 		gda_query_field_set_visible (GDA_QUERY_FIELD (field), (*prop == 't') ? TRUE : FALSE);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "is_internal");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_internal");
 	if (prop) {
 		gda_query_field_set_internal (GDA_QUERY_FIELD (field), (*prop == 't') ? TRUE : FALSE);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "g_type");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"g_type");
 	if (prop) {
 		field->priv->g_type = gda_g_type_from_string (prop);
 		dh = gda_dict_get_default_handler (dict, field->priv->g_type);
@@ -1158,7 +1193,7 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 			field->priv->value = gda_value_new_null ();
 	}
 
-	prop = xmlGetProp (node, "dict_type");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"dict_type");
 	if (prop) {
 		GdaDictType *dict_type;
 		dict_type = gda_dict_get_dict_type_by_xml_id (dict, prop);
@@ -1169,7 +1204,7 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "value");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"value");
 	if (prop) {
 		if (dh) {
 			field->priv->value = gda_data_handler_get_value_from_str (dh, prop, field->priv->g_type);
@@ -1186,11 +1221,11 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "default");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"default");
 	if (prop) {
 		gchar *str2;
 
-		str2 = xmlGetProp (node, "default_g_type");
+		str2 = (gchar*)xmlGetProp(node, (xmlChar*)"default_g_type");
 		if (str2) {
 			GdaDataHandler *dh2;
 			GType vtype;
@@ -1206,23 +1241,23 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "is_param");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_param");
 	if (prop) {
 		field->priv->is_parameter = (*prop == 't') ? TRUE : FALSE;
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "nullok");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"nullok");
 	if (prop) {
 		field->priv->is_null_allowed = (*prop == 't') ? TRUE : FALSE;
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "plugin");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"plugin");
 	if (prop) 
 		field->priv->plugin = prop;
 
-	prop = xmlGetProp (node, "restrict");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"restrict");
 	if (prop) {
 		GdaDataModel *model = NULL;
 		gint col = -1;
@@ -1275,7 +1310,7 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "alias");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"alias");
 	if (prop) {
 		gda_query_field_set_alias (GDA_QUERY_FIELD (field), prop);
 		xmlFree (prop);
@@ -1310,12 +1345,29 @@ gda_query_field_value_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GErr
  * GdaRenderer interface implementation
  */
 
+static GdaParameter *
+gda_query_field_value_render_find_param (GdaQueryFieldValue *field, GdaParameterList *context)
+{
+	GSList *list, *for_fields;
+	if (!context)
+		return NULL;
+		
+	for (list = context->parameters; list; list = list->next) {
+		for_fields = gda_parameter_get_param_users (GDA_PARAMETER (list->data));
+		if (g_slist_find (for_fields, field))
+			return GDA_PARAMETER (list->data);
+	}
+
+	return NULL;
+}
+
 static gboolean
 gda_query_field_value_render_find_value (GdaQueryFieldValue *field, GdaParameterList *context, 
-			       const GValue **value_found, GdaParameter **param_source)
+					 const GValue **value_found, GdaParameter **param_source)
 {
 	const GValue *cvalue = NULL;
 	gboolean found = FALSE;
+	GdaParameter *param;
 
 	if (param_source)
 		*param_source = NULL;
@@ -1323,20 +1375,12 @@ gda_query_field_value_render_find_value (GdaQueryFieldValue *field, GdaParameter
 		*value_found = NULL;
 
 	/* looking for a value into the context first */
-	if (context) {
-		GSList *list = context->parameters;
-		GSList *for_fields;
-		
-		while (list && !found) {
-			for_fields = gda_parameter_get_param_users (GDA_PARAMETER (list->data));
-			if (g_slist_find (for_fields, field)) {
-				if (param_source)
-					*param_source = GDA_PARAMETER (list->data);
-				found = TRUE;
-				cvalue = gda_parameter_get_value (GDA_PARAMETER (list->data));
-			}
-			list = g_slist_next (list);
-		}
+	param = gda_query_field_value_render_find_param (field, context);
+	if (param) {
+		if (param_source)
+			*param_source = param;
+		cvalue = gda_parameter_get_value (param);
+		found = TRUE;
 	}
 	
 	/* using the field's value, if available */
@@ -1352,12 +1396,12 @@ gda_query_field_value_render_find_value (GdaQueryFieldValue *field, GdaParameter
 }
 
 static gchar *
-gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
+				     GSList **out_params_used, guint options, GError **error)
 {
 	gchar *str = NULL;
 	GdaQueryFieldValue *field;
 	const GValue *value = NULL;
-	gboolean sqlext = options & GDA_RENDERER_EXTRA_VAL_ATTRS;
 	GdaDict *dict;
 
 	g_return_val_if_fail (iface && GDA_IS_QUERY_FIELD_VALUE (iface), NULL);
@@ -1366,6 +1410,51 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 
 	dict = gda_object_get_dict (GDA_OBJECT (field));
 
+	/* specific rendering of parameters, where actual value is not used */
+	if (field->priv->is_parameter && (options & (GDA_RENDERER_PARAMS_AS_COLON | GDA_RENDERER_PARAMS_AS_DOLLAR))) {
+		GdaParameter *param_source;
+
+		g_return_val_if_fail (out_params_used, NULL);
+
+		param_source = gda_query_field_value_render_find_param (field, context);
+		if (param_source) {
+			gboolean use_default;
+			g_object_get (G_OBJECT (param_source), "use_default_value", &use_default, NULL);
+			if (use_default) {
+				if (options & GDA_RENDERER_ERROR_IF_DEFAULT) {
+					g_set_error (error,
+						     GDA_QUERY_FIELD_VALUE_ERROR,
+						     GDA_QUERY_FIELD_VALUE_DEFAULT_PARAM_ERROR,
+						     _("Default value requested"));
+					return NULL;
+				}
+			}
+
+			if (!g_slist_find (*out_params_used, param_source))
+				*out_params_used = g_slist_append (*out_params_used, param_source);
+			
+			if (options & GDA_RENDERER_PARAMS_AS_COLON) {
+				gchar *name = gda_parameter_get_alphanum_name (param_source);
+				str = g_strdup_printf (":%s", name);
+				g_free (name);
+			}
+			else {
+				gint i;
+				i = g_slist_index (*out_params_used, param_source) + 1;	
+				str = g_strdup_printf ("$%d", i);
+			}
+			return str;
+		}
+		else {
+			g_set_error (error,
+				     GDA_QUERY_FIELD_VALUE_ERROR,
+				     GDA_QUERY_FIELD_VALUE_RENDER_ERROR,
+				     _("Could not find GdaParameter in context for value field '%s'"), 
+				     gda_object_get_name (GDA_OBJECT (field)));
+			return NULL;
+		}
+	}
+
 	if (field->priv->is_parameter) {
 		gboolean value_found;
 		GdaParameter *param_source = NULL;
@@ -1402,10 +1491,10 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 						g_set_error (error,
 							     GDA_QUERY_FIELD_VALUE_ERROR,
 							     GDA_QUERY_FIELD_VALUE_DEFAULT_PARAM_ERROR,
-							     "Default value requested");
+							     _("Default value requested"));
 						return NULL;
 					}
-					else
+					else 
 						str = g_strdup ("DEFAULT");
 				}
 			}
@@ -1418,8 +1507,10 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 						str = gda_data_handler_get_sql_from_value (dh, value);
 				}
 				if (!str)
-					str = g_strdup ("NULL");	
+					str = g_strdup ("NULL");
 			}
+			if (out_params_used && !g_slist_find (*out_params_used, param_source))
+				*out_params_used = g_slist_append (*out_params_used, param_source);
 		}
 		else {
 			if (field->priv->is_null_allowed)
@@ -1452,7 +1543,7 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 			str = g_strdup ("NULL");	
 	}
 
-	if (sqlext && field->priv->is_parameter) {
+	if (field->priv->is_parameter && (options & GDA_RENDERER_PARAMS_AS_DETAILED)) {
 		GString *extra = g_string_new ("");
 		const gchar *tmpstr;
 		gchar *str2;
@@ -1460,7 +1551,7 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 
 		/* add extra information about the value, as an extension of SQL */
 		if (! field->priv->is_parameter) {
-			g_string_append (extra, ":isparam=\"FALSE\"");
+			g_string_append (extra, "isparam:\"FALSE\"");
 			isfirst = FALSE;
 		}
 
@@ -1469,11 +1560,11 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 		else
 			g_string_append (extra, " ");
 		if (field->priv->dict_type)
-			g_string_append_printf (extra, ":type=\"%s\"", 
+			g_string_append_printf (extra, "type:\"%s\"", 
 						gda_object_get_name (GDA_OBJECT (field->priv->dict_type)));
 		else
 			/* print g_type instead */
-			g_string_append_printf (extra, ":type=\"%s\"", gda_g_type_to_string (field->priv->g_type));
+			g_string_append_printf (extra, "type:\"%s\"", gda_g_type_to_string (field->priv->g_type));
 
 		tmpstr = gda_object_get_name (GDA_OBJECT (field));
 		if (tmpstr && *tmpstr) {
@@ -1482,7 +1573,7 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 			else
 				g_string_append (extra, " ");
 
-			g_string_append_printf (extra, ":name=\"%s\"", tmpstr);
+			g_string_append_printf (extra, "name:\"%s\"", tmpstr);
 		}
 
 
@@ -1492,7 +1583,7 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 				isfirst = FALSE;
 			else
 				g_string_append (extra, " ");
-			g_string_append_printf (extra, ":descr=\"%s\"", tmpstr);
+			g_string_append_printf (extra, "descr:\"%s\"", tmpstr);
 		}
 
 		if (field->priv->is_null_allowed) {
@@ -1500,10 +1591,10 @@ gda_query_field_value_render_as_sql (GdaRenderer *iface, GdaParameterList *conte
 				isfirst = FALSE;
 			else
 				g_string_append (extra, " ");
-			g_string_append (extra, ":nullok=\"TRUE\"");
+			g_string_append (extra, "nullok:TRUE");
 		}
 
-		str2 = g_strdup_printf ("%s [%s]", str, extra->str);
+		str2 = g_strdup_printf ("%s /* %s */", str, extra->str);
 		g_free (str);
 		str = str2;
 
@@ -1521,7 +1612,7 @@ gda_query_field_value_render_as_str (GdaRenderer *iface, GdaParameterList *conte
 	g_return_val_if_fail (iface && GDA_IS_QUERY_FIELD_VALUE (iface), NULL);
 	g_return_val_if_fail (GDA_QUERY_FIELD_VALUE (iface)->priv, NULL);
 	
-	str = gda_query_field_value_render_as_sql (iface, context, 0, NULL);
+	str = gda_query_field_value_render_as_sql (iface, context, NULL, 0, NULL);
 	if (!str)
 		str = g_strdup ("???");
 	return str;
