@@ -214,19 +214,22 @@ gda_query_join_class_init (GdaQueryJoinClass * class)
 	object_class->get_property = gda_query_join_get_property;
 
 	g_object_class_install_property (object_class, PROP_QUERY,
-					 g_param_spec_pointer ("query", "Query to which the field belongs", NULL, 
+					 g_param_spec_object ("query", "Query to which the field belongs", NULL, 
+                                                               GDA_TYPE_QUERY,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE |
 								G_PARAM_CONSTRUCT_ONLY)));
 
 	g_object_class_install_property (object_class, PROP_TARGET1_OBJ,
-					 g_param_spec_pointer ("target1", "A pointer to a GdaQueryTarget", NULL, 
+					 g_param_spec_object ("target1", "A pointer to a GdaQueryTarget", NULL, 
+                                                               GDA_TYPE_QUERY_TARGET,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_TARGET1_ID,
 					 g_param_spec_string ("target1_id", "XML ID of a target", NULL, NULL,
 							      G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_TARGET2_OBJ,
-					 g_param_spec_pointer ("target2", "A pointer to a GdaQueryTarget", NULL, 
+					 g_param_spec_object ("target2", "A pointer to a GdaQueryTarget", NULL, 
+                                                               GDA_TYPE_QUERY_TARGET,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_TARGET2_ID,
 					 g_param_spec_string ("target2_id", "XML ID of a target", NULL, NULL,
@@ -354,6 +357,7 @@ gda_query_join_new_copy (GdaQueryJoin *orig, GHashTable *replacements)
 	dict = gda_object_get_dict (GDA_OBJECT (orig));
 	obj = g_object_new (GDA_TYPE_QUERY_JOIN, "dict", dict, 
 			    "query", query, NULL);
+	g_object_unref (query);
 	join = GDA_QUERY_JOIN (obj);
 	if (replacements)
 		g_hash_table_insert (replacements, orig, join);
@@ -520,7 +524,6 @@ gda_query_join_set_property (GObject *object,
 			     const GValue *value,
 			     GParamSpec *pspec)
 {
-	gpointer ptr;
 	GdaQueryJoin *join;
 	GdaDict *dict;
 	const gchar *str;
@@ -528,8 +531,8 @@ gda_query_join_set_property (GObject *object,
 	join = GDA_QUERY_JOIN (object);
 	if (join->priv) {
 		switch (param_id) {
-		case PROP_QUERY:
-			ptr = g_value_get_pointer (value);
+		case PROP_QUERY: {
+			GdaQuery* ptr = GDA_QUERY (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_QUERY (ptr));
 			dict = gda_object_get_dict (GDA_OBJECT (join));
 			g_return_if_fail (gda_object_get_dict (GDA_OBJECT (ptr)) == dict);
@@ -562,21 +565,24 @@ gda_query_join_set_property (GObject *object,
 					  G_CALLBACK (target_ref_lost_cb), join);
 
 			break;
-		case PROP_TARGET1_OBJ:
-			ptr = g_value_get_pointer (value);
+                }
+		case PROP_TARGET1_OBJ: {
+			GdaQueryTarget* ptr = GDA_QUERY_TARGET (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_QUERY_TARGET (ptr));
 			gda_object_ref_set_ref_object (join->priv->target1, GDA_OBJECT (ptr));
 			break;
+                }
 		case PROP_TARGET1_ID:
 			str = g_value_get_string (value);
 			gda_object_ref_set_ref_name (join->priv->target1, GDA_TYPE_QUERY_TARGET, 
 						     REFERENCE_BY_XML_ID, str);
 			break;
-		case PROP_TARGET2_OBJ:
-			ptr = g_value_get_pointer (value);
+		case PROP_TARGET2_OBJ: {
+			GdaQueryTarget* ptr = GDA_QUERY_TARGET (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_QUERY_TARGET (ptr));
 			gda_object_ref_set_ref_object (join->priv->target2, GDA_OBJECT (ptr));
 			break;
+                }
 		case PROP_TARGET2_ID:
 			str = g_value_get_string (value);
 			gda_object_ref_set_ref_name (join->priv->target2, GDA_TYPE_QUERY_TARGET, 
@@ -598,13 +604,13 @@ gda_query_join_get_property (GObject *object,
 	if (join->priv) {
 		switch (param_id) {
 			case PROP_QUERY:
-			g_value_set_pointer (value, join->priv->query);
+			g_value_set_object (value, G_OBJECT (join->priv->query));
 			break;
 		case PROP_TARGET1_OBJ:
-			g_value_set_pointer (value, gda_object_ref_get_ref_object (join->priv->target1));
+			g_value_set_object (value, G_OBJECT (gda_object_ref_get_ref_object (join->priv->target1)));
 			break;
 		case PROP_TARGET2_OBJ:
-			g_value_set_pointer (value, gda_object_ref_get_ref_object (join->priv->target2));
+			g_value_set_object (value, G_OBJECT (gda_object_ref_get_ref_object (join->priv->target2)));
 			break;
 		default:
 			g_assert_not_reached ();
@@ -1211,7 +1217,7 @@ gda_query_join_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	join = GDA_QUERY_JOIN (iface);
 
-	node = xmlNewNode (NULL, "gda_query_join");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_query_join");
 	
 	/* targets */
 	if (join->priv->target1) {
@@ -1225,7 +1231,7 @@ gda_query_join_save_to_xml (GdaXmlStorage *iface, GError **error)
 			str = g_strdup (gda_object_ref_get_ref_name (join->priv->target1, NULL, NULL));
 		
 		if (str) {
-			xmlSetProp (node, "target1", str);
+			xmlSetProp(node, (xmlChar*)"target1", (xmlChar*)str);
 			g_free (str);
 		}
 	}
@@ -1241,14 +1247,14 @@ gda_query_join_save_to_xml (GdaXmlStorage *iface, GError **error)
 			str = g_strdup (gda_object_ref_get_ref_name (join->priv->target2, NULL, NULL));
 		
 		if (str) {
-			xmlSetProp (node, "target2", str);
+			xmlSetProp(node, (xmlChar*)"target2", (xmlChar*)str);
 			g_free (str);
 		}
 	}
 
 	/* join type */
 	type = convert_join_type_to_str (join->priv->join_type);
-	xmlSetProp (node, "join_type", type);
+	xmlSetProp(node, (xmlChar*)"join_type", (xmlChar*)type);
 
 	/* join condition */
 	if (join->priv->cond) {
@@ -1278,7 +1284,7 @@ gda_query_join_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 	g_return_val_if_fail (node, FALSE);
 
 	join = GDA_QUERY_JOIN (iface);
-	if (strcmp (node->name, "gda_query_join")) {
+	if (strcmp ((gchar*)node->name, "gda_query_join")) {
 		g_set_error (error,
 			     GDA_QUERY_JOIN_ERROR,
 			     GDA_QUERY_JOIN_XML_LOAD_ERROR,
@@ -1286,7 +1292,7 @@ gda_query_join_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 		return FALSE;
 	}
 
-	prop = xmlGetProp (node, "target1");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"target1");
 	if (prop) {
 		if (join->priv->target1) {
 			gda_object_ref_set_ref_name (join->priv->target1, GDA_TYPE_QUERY_TARGET, 
@@ -1295,7 +1301,7 @@ gda_query_join_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 		}
 		g_free (prop);
 	}
-	prop = xmlGetProp (node, "target2");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"target2");
 	if (prop) {
 		if (join->priv->target2) {
 			gda_object_ref_set_ref_name (join->priv->target2, GDA_TYPE_QUERY_TARGET, 
@@ -1304,7 +1310,7 @@ gda_query_join_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 		}
 		g_free (prop);
 	}
-	prop = xmlGetProp (node, "join_type");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"join_type");
 	if (prop) {
 		join->priv->join_type = convert_str_to_join_type (prop);
 		g_free (prop);
@@ -1313,7 +1319,7 @@ gda_query_join_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 	/* children nodes */
 	children = node->children;
 	while (children) {
-		if (!strcmp (children->name, "gda_query_cond")) {
+		if (!strcmp ((gchar*)children->name, "gda_query_cond")) {
 			GdaQueryCondition *cond;
 
 			cond = gda_query_condition_new (join->priv->query, GDA_QUERY_CONDITION_NODE_AND);
