@@ -1,6 +1,6 @@
 /* gda-query-target.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -63,7 +63,8 @@ static void        gda_query_target_replace_refs        (GdaReferer *iface, GHas
 
 /* Renderer interface */
 static void        gda_query_target_renderer_init   (GdaRendererIface *iface);
-static gchar      *gda_query_target_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar      *gda_query_target_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+						     GSList **out_params_used, guint options, GError **error);
 static gchar      *gda_query_target_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Alias interface */
@@ -196,12 +197,14 @@ gda_query_target_class_init (GdaQueryTargetClass * class)
 	object_class->set_property = gda_query_target_set_property;
 	object_class->get_property = gda_query_target_get_property;
 	g_object_class_install_property (object_class, PROP_QUERY,
-					 g_param_spec_pointer ("query", "Query to which the target belongs", NULL, 
+					 g_param_spec_object ("query", "Query to which the target belongs", NULL, 
+                                                               GDA_TYPE_QUERY,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE |
 								G_PARAM_CONSTRUCT_ONLY)));
 
 	g_object_class_install_property (object_class, PROP_ENTITY_OBJ,
-					 g_param_spec_pointer ("entity", "A pointer to a GdaEntity", NULL, 
+					 g_param_spec_object ("entity", "A pointer to a GdaEntity", NULL, 
+                                                               GDA_TYPE_ENTITY,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_ENTITY_NAME,
 					 g_param_spec_string ("entity_name", "Name an entity", NULL, NULL,
@@ -358,7 +361,6 @@ gda_query_target_set_property (GObject *object,
 			       const GValue *value,
 			       GParamSpec *pspec)
 {
-	gpointer ptr;
 	GdaQueryTarget *target;
 	guint id;
 	const gchar *str;
@@ -367,8 +369,8 @@ gda_query_target_set_property (GObject *object,
 	target = GDA_QUERY_TARGET (object);
 	if (target->priv) {
 		switch (param_id) {
-		case PROP_QUERY:
-			ptr = g_value_get_pointer (value);
+		case PROP_QUERY: {
+			GdaQuery* ptr = GDA_QUERY (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_QUERY (ptr));
 			g_return_if_fail (gda_object_get_dict (GDA_OBJECT (ptr)) == gda_object_get_dict (GDA_OBJECT (target)));
 			
@@ -389,11 +391,13 @@ gda_query_target_set_property (GObject *object,
 			g_object_get (G_OBJECT (ptr), "target_serial", &id, NULL);
 			gda_query_object_set_int_id (GDA_QUERY_OBJECT (target), id);
 			break;
-		case PROP_ENTITY_OBJ:
-			ptr = g_value_get_pointer (value);
+                }
+		case PROP_ENTITY_OBJ: {
+			GdaEntity* ptr = GDA_ENTITY (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_ENTITY (ptr));
 			gda_object_ref_set_ref_object (target->priv->entity_ref, GDA_OBJECT (ptr));
 			break;
+                }
 		case PROP_ENTITY_NAME:
 			str = g_value_get_string (value);
 			gda_object_ref_set_ref_name (target->priv->entity_ref, GDA_TYPE_DICT_TABLE, 
@@ -425,10 +429,10 @@ gda_query_target_get_property (GObject *object,
 	if (target->priv) {
 		switch (param_id) {
 		case PROP_QUERY:
-			g_value_set_pointer (value, target->priv->query);
+			g_value_set_object (value, G_OBJECT (target->priv->query));
 			break;
 		case PROP_ENTITY_OBJ:
-			g_value_set_pointer (value, gda_object_ref_get_ref_object (target->priv->entity_ref));
+			g_value_set_object (value, G_OBJECT (gda_object_ref_get_ref_object (target->priv->entity_ref)));
 			break;
 		case PROP_ENTITY_NAME:
 		case PROP_ENTITY_ID:
@@ -733,10 +737,10 @@ gda_query_target_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	target = GDA_QUERY_TARGET (iface);
 
-	node = xmlNewNode (NULL, "gda_query_target");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_query_target");
 	
 	str = gda_xml_storage_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
 	
 	if (target->priv->entity_ref) {
@@ -746,7 +750,7 @@ gda_query_target_save_to_xml (GdaXmlStorage *iface, GError **error)
 		if (base) {
 			str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (base));
 			if (str) {
-				xmlSetProp (node, "entity_ref", str);
+				xmlSetProp(node, (xmlChar*)"entity_ref", (xmlChar*)str);
 				g_free (str);
 			}
 			else {
@@ -760,7 +764,7 @@ gda_query_target_save_to_xml (GdaXmlStorage *iface, GError **error)
 		else {
 			str = (gchar *) gda_object_ref_get_ref_name (target->priv->entity_ref, NULL, NULL);
 			if (str) 
-				xmlSetProp (node, "table_name", str);
+				xmlSetProp(node, (xmlChar*)"table_name", (xmlChar*)str);
 			else {
 				g_set_error (error, GDA_QUERY_TARGET_ERROR,
 					     GDA_QUERY_TARGET_XML_SAVE_ERROR,
@@ -787,7 +791,7 @@ gda_query_target_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **
 	g_return_val_if_fail (node, FALSE);
 
 	target = GDA_QUERY_TARGET (iface);
-	if (strcmp (node->name, "gda_query_target")) {
+	if (strcmp ((gchar*)node->name, "gda_query_target")) {
 		g_set_error (error,
 			     GDA_QUERY_TARGET_ERROR,
 			     GDA_QUERY_TARGET_XML_LOAD_ERROR,
@@ -795,7 +799,7 @@ gda_query_target_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **
 		return FALSE;
 	}
 
-	str = xmlGetProp (node, "id");
+	str = (gchar*)xmlGetProp(node, (xmlChar*)"id");
 	if (str) {
 		gchar *tok, *ptr;
 
@@ -818,7 +822,7 @@ gda_query_target_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **
 		g_free (str);
 	}
 
-	str = xmlGetProp (node, "entity_ref");
+	str = (char*)xmlGetProp(node, (xmlChar*)"entity_ref");
 	if (str) {
 		GType target_ref;
 		const gchar *name;
@@ -844,7 +848,7 @@ gda_query_target_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **
 		g_free (str);
 	}
 	else {
-		str = xmlGetProp (node, "table_name");
+		str = (gchar*)xmlGetProp(node, (xmlChar*)"table_name");
 		if (str) {
 			g_assert (target->priv->entity_ref);
 			gda_object_ref_set_ref_name (target->priv->entity_ref, GDA_TYPE_DICT_TABLE, 
@@ -872,13 +876,22 @@ gda_query_target_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **
  */
 
 static gchar *
-gda_query_target_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_query_target_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
+				GSList **out_params_used, guint options, GError **error)
 {
 	gchar *str;
 	GString *string = NULL;
 	GdaQueryTarget *target;
 	GdaEntity *entity;
 	gboolean err = FALSE;
+	GdaServerProviderInfo *sinfo = NULL;
+	GdaDict *dict;
+	GdaConnection *cnc;
+	
+	dict = gda_object_get_dict (GDA_OBJECT (iface));
+	cnc = gda_dict_get_connection (dict);
+	if (cnc)
+		sinfo = gda_connection_get_infos (cnc);
 
 	g_return_val_if_fail (GDA_IS_QUERY_TARGET (iface), NULL);
 	g_return_val_if_fail (GDA_QUERY_TARGET (iface)->priv, NULL);
@@ -887,24 +900,24 @@ gda_query_target_render_as_sql (GdaRenderer *iface, GdaParameterList *context, g
 	entity = gda_query_target_get_represented_entity (target);
 	if (entity) {
 		if (GDA_IS_DICT_TABLE (entity)) {
-			gchar *tmp, *tname;
+			gchar *tmp = NULL, *tname;
 
 			tname = (gchar *) gda_object_get_name (GDA_OBJECT (entity));
-			tmp = g_utf8_strdown (tname, -1);
-			if (((*tmp <= '9') && (*tmp >= '0')) || 
-			    strcmp (tmp, tname)) {
-				g_free (tmp);
-				tmp = tname;
-				tname = g_strdup_printf ("\"%s\"", tmp);
+			if (!sinfo || sinfo->quote_non_lc_identifiers) {
+				tmp = g_utf8_strdown (tname, -1);
+				if (((*tmp <= '9') && (*tmp >= '0')) || strcmp (tmp, tname)) {
+					g_free (tmp);
+					tname = g_strdup_printf ("\"%s\"", tname);
+					tmp = tname;
+				}
 			}
-			else
-				g_free (tmp);
-			string = g_string_new (tname);
+			string = g_string_new (tname);			
+			g_free (tmp);
 		}
 		
 		if (GDA_IS_QUERY (entity)) {
 			string = g_string_new ("(");
-			str = gda_renderer_render_as_sql (GDA_RENDERER (entity), context, options, error);
+			str = gda_renderer_render_as_sql (GDA_RENDERER (entity), context, out_params_used, options, error);
 			if (str) {
 				g_string_append (string, str);
 				g_free (str);
@@ -928,16 +941,7 @@ gda_query_target_render_as_sql (GdaRenderer *iface, GdaParameterList *context, g
 	}
 
 	if (!err) {
-		/* adding alias */
-		GdaServerProviderInfo *sinfo = NULL;
-		GdaDict *dict;
-		GdaConnection *cnc;
-		
-		dict = gda_object_get_dict (GDA_OBJECT (target));
-		cnc = gda_dict_get_connection (dict);
-		if (cnc)
-			sinfo = gda_connection_get_infos (cnc);
-	
+		/* adding alias */	
 		if (!sinfo || sinfo->supports_alias) {
 			if (!sinfo || sinfo->alias_needs_as_keyword)
 				g_string_append (string, " AS ");
