@@ -30,6 +30,7 @@
 #include <libgda/gda-parameter-list.h>
 #include <libgda/gda-parameter.h>
 #include <libgda/gda-connection.h>
+#include <libgda/gda-data-model-private.h> /* For #include <libgda/gda-dict.h>() */
 #include "gda-util.h"
 #include <string.h>
 #ifdef HAVE_LOCALE_H
@@ -165,13 +166,16 @@ gda_server_operation_class_init (GdaServerOperationClass *klass)
 	object_class->get_property = gda_server_operation_get_property;
 
 	g_object_class_install_property (object_class, PROP_DICT,
-					 g_param_spec_pointer ("dict", NULL, NULL, 
+					 g_param_spec_object ("dict", NULL, NULL, 
+                                                               GDA_TYPE_DICT,
 							       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (object_class, PROP_CNC,
-					 g_param_spec_pointer ("connection", NULL, NULL, 
+					 g_param_spec_object ("connection", NULL, NULL, 
+                                                               GDA_TYPE_CONNECTION,
 							       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (object_class, PROP_PROV,
-					 g_param_spec_pointer ("provider_obj", NULL, NULL, 
+					 g_param_spec_object ("provider_obj", NULL, NULL, 
+                                                               GDA_TYPE_SERVER_PROVIDER,
 							       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (object_class, PROP_SPEC_FILE,
 					 g_param_spec_string ("spec_file", NULL, NULL, 
@@ -516,14 +520,14 @@ gda_server_operation_set_property (GObject *object,
 			if (op->priv->dict)
 				g_object_unref (op->priv->dict);
 
-			op->priv->dict = ASSERT_DICT (g_value_get_pointer (value));
+			op->priv->dict = ASSERT_DICT (g_value_get_object (value));
 			g_object_ref (op->priv->dict);
 			break;
 		case PROP_CNC:
 			if (op->priv->cnc)
 				g_object_unref (op->priv->cnc);
 
-			op->priv->cnc = g_value_get_pointer (value);
+			op->priv->cnc = GDA_CONNECTION( g_value_get_object (value));
 			op->priv->cnc_set = TRUE;
 
 			if (op->priv->cnc) {
@@ -539,10 +543,10 @@ gda_server_operation_set_property (GObject *object,
 			}
 			break;
 		case PROP_PROV:
-			if (g_value_get_pointer (value)) {
+			if (g_value_get_object (value)) {
 				if (op->priv->prov)
 					g_object_unref (op->priv->prov);
-				op->priv->prov = g_value_get_pointer (value);
+				op->priv->prov = g_value_get_object(value);
 				g_object_ref (op->priv->prov);
 			}
 			op->priv->prov_set = TRUE;
@@ -693,14 +697,14 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 		GSList *sources = NULL;
 	
 		node = specnode->children;
-		while (node && (xmlNodeIsText (node) || strcmp (node->name, "sources"))) 
+		while (node && (xmlNodeIsText (node) || strcmp ((gchar*)node->name, "sources"))) 
 		node = node->next; 
-		if (node && !strcmp (node->name, "sources")){
+		if (node && !strcmp ((gchar*)node->name, "sources")){
 			for (node = node->xmlChildrenNode; (node != NULL); node = node->next) {
 				if (xmlNodeIsText (node)) 
 					continue;
 				
-				if (!strcmp (node->name, "gda_array")) {
+				if (!strcmp ((gchar*)node->name, "gda_array")) {
 					GdaDataModel *model;
 					GSList *errors;
 					
@@ -713,9 +717,9 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 					else  {
 						xmlChar *str;
 						sources = g_slist_prepend (sources, model);
-						str = xmlGetProp (node, "name");
+						str = xmlGetProp(node, (xmlChar*)"name");
 						if (str) {
-							gda_object_set_name (GDA_OBJECT (model), str);
+							gda_object_set_name (GDA_OBJECT (model), (gchar*)str);
 							xmlFree (str);
 						}
 					}
@@ -740,8 +744,8 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 		}
 
 		/* don't care about entries for the wrong locale */
-		this_lang = xmlGetProp (node, "lang");
-		if (this_lang && strncmp (this_lang, lang, strlen (this_lang))) {
+		this_lang = xmlGetProp(node, (xmlChar*)"lang");
+		if (this_lang && strncmp ((gchar*)this_lang, lang, strlen ((gchar*)this_lang))) {
 			g_free (this_lang);
 			node = node->next;
 			continue;
@@ -749,7 +753,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 
 		id = xmlGetProp (node, BAD_CAST "id");
 		complete_path = g_strdup_printf ("%s/%s", root ? root : "", id);
-		path_name = g_strdup (id);
+		path_name = g_strdup ((gchar*)id);
 		if (id)
 			xmlFree (id);
 
@@ -760,7 +764,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 		}
 
 		/* GDA_SERVER_OPERATION_NODE_PARAMLIST */
-		if (!strcmp (node->name, "parameters")) {
+		if (!strcmp ((gchar*)node->name, "parameters")) {
 			GdaParameterList *plist;
 
 			plist = gda_parameter_list_new_from_spec_node (NULL, node, &error);
@@ -775,7 +779,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 			}
 		}
 		/* GDA_SERVER_OPERATION_NODE_DATA_MODEL */
-		else if (!strcmp (node->name, "gda_array")) {
+		else if (!strcmp ((gchar*)node->name, "gda_array")) {
 			GdaDataModel *import;
 
 			import = gda_data_model_import_new_xml_node (node);
@@ -792,7 +796,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 		}
 
 		/* GDA_SERVER_OPERATION_NODE_SEQUENCE */
-		else if (!strcmp (node->name, "sequence")) {
+		else if (!strcmp ((gchar*)node->name, "sequence")) {
 			GSList *seq_tmpl = NULL;
 			xmlChar *prop;
 
@@ -803,28 +807,28 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 			opnode->d.seq.seq_items = NULL;
 			opnode->d.seq.xml_spec = node;
 			
-			prop = xmlGetProp (node, "name");
+			prop = xmlGetProp(node, (xmlChar*)"name");
 			if (prop) {
-				opnode->d.seq.name = g_strdup (prop);
+				opnode->d.seq.name = g_strdup ((gchar*)prop);
 				xmlFree (prop);
 			}
 			
-			prop = xmlGetProp (node, "descr");
+			prop = xmlGetProp(node, (xmlChar*)"descr");
 			if (prop) {
-				opnode->d.seq.descr = g_strdup (prop);
+				opnode->d.seq.descr = g_strdup ((gchar*)prop);
 				xmlFree (prop);
 			}
 
 			
-			prop = xmlGetProp (node, "minitems");
+			prop = xmlGetProp(node, (xmlChar*)"minitems");
 			if (prop) {
-				opnode->d.seq.min_items = atoi (prop);
+				opnode->d.seq.min_items = atoi ((gchar*)prop);
 				xmlFree (prop);
 			}
 
-			prop = xmlGetProp (node, "maxitems");
+			prop = xmlGetProp(node, (xmlChar*)"maxitems");
 			if (prop) {
-				opnode->d.seq.max_items = atoi (prop);
+				opnode->d.seq.max_items = atoi ((gchar*)prop);
 				xmlFree (prop);
 			}
 
@@ -833,7 +837,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 		}
 
 		/* GDA_SERVER_OPERATION_NODE_PARAM */
-		else if (!strcmp (node->name, "parameter")) {
+		else if (!strcmp ((gchar*)node->name, "parameter")) {
 			GdaParameter *param = NULL;
 			GdaDictType *dtype = NULL;
 			xmlChar *dbmstype, *gdatype;
@@ -843,8 +847,8 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 			/* find data type and create GdaParameter */
 			dbmstype = xmlGetProp (node, BAD_CAST "dbmstype");
 			gdatype = xmlGetProp (node, BAD_CAST "gdatype");
-			dtype = utility_find_or_create_data_type (op->priv->dict, op->priv->prov, op->priv->cnc,
-								  dbmstype, gdatype, &dtype_created);
+			dtype = gda_utility_find_or_create_data_type (op->priv->dict, op->priv->prov, op->priv->cnc,
+								  (gchar*)dbmstype, (gchar*)gdatype, &dtype_created);
 			if (dbmstype) xmlFree (dbmstype);
 			if (gdatype) xmlFree (gdatype);
 			if (!dtype) {
@@ -855,13 +859,13 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 			}
 			else {
 				param = GDA_PARAMETER (g_object_new (GDA_TYPE_PARAMETER, "dict", op->priv->dict,
-								     "gda_type", gda_dict_type_get_gda_type (dtype),
+								     "g_type", gda_dict_type_get_g_type (dtype),
 								     NULL));
 				if (dtype_created)
 					g_object_unref (dtype);
 			
 				/* set parameter's attributes */
-				utility_parameter_load_attributes (param, node, op->priv->sources);
+				gda_utility_parameter_load_attributes (param, node, op->priv->sources);
 
 				opnode = node_new (parent, GDA_SERVER_OPERATION_NODE_PARAM, path_name);
 				opnode->d.param = param;
@@ -880,7 +884,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root)
 			/* status */
 			status = xmlGetProp (node, BAD_CAST "status");
 			if (status) {
-				if (!strcmp (status, "OPT"))
+				if (!strcmp ((gchar*)status, "OPT"))
 					opnode->status = GDA_SERVER_OPERATION_STATUS_OPTIONAL;
 				xmlFree (status);
 			}
@@ -1152,11 +1156,11 @@ node_save (GdaServerOperation *op, Node *opnode, xmlNodePtr parent)
 				else
 					str = gda_value_stringify (value);
 			}
-			node = xmlNewChild (parent, NULL, BAD_CAST "op_data", str);
+			node = xmlNewChild (parent, NULL, BAD_CAST "op_data", (xmlChar*)str);
 			g_free (str);
 
 			path = g_strdup_printf ("%s/%s", complete_path, gda_object_get_id (GDA_OBJECT (list->data)));
-			xmlSetProp (node, "path", path);
+			xmlSetProp(node, (xmlChar*)"path", (xmlChar*)path);
 			g_free (path);
 
 			list = g_slist_next (list);
@@ -1164,8 +1168,8 @@ node_save (GdaServerOperation *op, Node *opnode, xmlNodePtr parent)
 		break;
 	case GDA_SERVER_OPERATION_NODE_DATA_MODEL:
 		node = xmlNewChild (parent, NULL, BAD_CAST "op_data", NULL);
-		xmlSetProp (node, "path", complete_path);
-		utility_data_model_dump_data_to_xml (opnode->d.model, node, NULL, 0, TRUE);
+		xmlSetProp(node, (xmlChar*)"path", (xmlChar*)complete_path);
+		gda_utility_data_model_dump_data_to_xml (opnode->d.model, node, NULL, 0, NULL, 0, TRUE);
 		break;
 	case GDA_SERVER_OPERATION_NODE_PARAM: {
 		const GValue *value;
@@ -1180,9 +1184,9 @@ node_save (GdaServerOperation *op, Node *opnode, xmlNodePtr parent)
 			else
 				str = gda_value_stringify (value);
 		}
-		node = xmlNewChild (parent, NULL, BAD_CAST "op_data", str);
+		node = xmlNewChild (parent, NULL, BAD_CAST "op_data", (xmlChar*)str);
 		g_free (str);
-		xmlSetProp (node, "path", complete_path);
+		xmlSetProp(node, (xmlChar*)"path", (xmlChar*)complete_path);
 		break;
 	}
 	case GDA_SERVER_OPERATION_NODE_SEQUENCE: {
@@ -1256,7 +1260,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 	}
 
 	/* actual data loading */
-	if (strcmp (node->name, "serv_op_data")) {
+	if (strcmp ((gchar*)node->name, "serv_op_data")) {
 		g_set_error (error, 0, 0,
 			     _("Expected tag <serv_op_data>, got <%s>"), node->name);
 		return FALSE;
@@ -1270,24 +1274,24 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 			continue;
 		}
 
-		if (strcmp (cur->name, "op_data")) {
+		if (strcmp ((gchar*)cur->name, "op_data")) {
 			g_set_error (error, 0, 0,
 				     _("Expected tag <op_data>, got <%s>"), cur->name);
 			return FALSE;
 		}
 
-		prop = xmlGetProp (cur, "path");
+		prop = xmlGetProp(cur, (xmlChar*)"path");
 		if (prop) {
 			Node *opnode;
 			gchar *extension = NULL;
 			gboolean allok = TRUE;
 
-			opnode = node_find_or_create (op, prop);
+			opnode = node_find_or_create (op, (gchar*)prop);
 			if (!opnode) {
 				/* try to see if the "parent" is a real node */
 				gchar *str;
 
-				str = gda_server_operation_get_node_parent (op, prop);
+				str = gda_server_operation_get_node_parent (op, (gchar*)prop);
 				if (str) {
 					opnode = node_find (op, str);
 					if (opnode && (opnode->type != GDA_SERVER_OPERATION_NODE_PARAMLIST))
@@ -1295,7 +1299,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 					g_free (str);
 				}
 				if (opnode)
-					extension = gda_server_operation_get_node_path_portion (op, prop);
+					extension = gda_server_operation_get_node_path_portion (op, (gchar*)prop);
 			}
 
 			if (opnode) {
@@ -1314,7 +1318,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 							GdaParameter *param;
 							param = gda_parameter_list_find_param (opnode->d.plist, extension);
 							if (param && 
-							    !gda_parameter_set_value_str (param, contents->content)) {
+							    !gda_parameter_set_value_str (param, (gchar*)contents->content)) {
 								g_set_error (error, 0, 0,
 									     _("Could not set parameter '%s' to value '%s'"), 
 									     prop, cur->content);
@@ -1333,7 +1337,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 
 					contents = cur->children;
 					if (contents && xmlNodeIsText (contents) && 
-					    !gda_parameter_set_value_str (opnode->d.param, contents->content)) {
+					    !gda_parameter_set_value_str (opnode->d.param, (gchar*)contents->content)) {
 						g_set_error (error, 0, 0,
 							     _("Could not set parameter '%s' to value '%s'"), prop, cur->content);
 						allok = FALSE;
@@ -1349,8 +1353,8 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 				}
 			}
 
-			xmlFree (prop);
 			g_free (extension);
+			xmlFree (prop);
 
 			if (!allok)
 				return FALSE;
@@ -1756,8 +1760,10 @@ gda_server_operation_del_item_from_sequence (GdaServerOperation *op, const gchar
  * gda_server_operation_get_value_at
  * @op: a #GdaServerOperation object
  * @path_format: a complete path to a node (starting with "/")
+ * @...: arguments to use with @path_format to make a complete path
  *
- * Get the value for the node at @path
+ * Get the value for the node at the path formed using @path_format and ... (the rules are the same as
+ * for g_strdup_printf())
  *
  * Returns: a constant #GValue if a value has been defined, or %NULL if the value is undefined or
  * if the @path is not defined or @path does not hold any value.
@@ -1822,6 +1828,179 @@ gda_server_operation_get_value_at (GdaServerOperation *op, const gchar *path_for
 	return value;
 }
 
+/**
+ * gda_server_operation_set_value_at
+ * @op: a #GdaServerOperation object
+ * @value: a string
+ * @error: a place to store errors or %NULL
+ * @path_format: a complete path to a node (starting with "/")
+ * @...: arguments to use with @path_format to make a complete path
+ *
+ * Set the value for the node at the path formed using @path_format and ... the rules are the same as
+ * for g_strdup_printf())
+ *
+ * Here are the corner cases:
+ * <itemizedlist>
+ *  <listitem><para>If the path corresponds to a #GdaParameter, then the parameter is set to @value</para></listitem>
+ *  <listitem><para>If the path corresponds to a sequence item like for example "/SEQUENCE_NAME/5/NAME" for
+ *     the "NAME" value of the 6th item of the "SEQUENCE_NAME" sequence then:
+ *     <itemizedlist>
+ *        <listitem><para>if the sequence already has 6 or more items, then the value is just set to the corresponding 
+ *           value in the 6th item of the sequence</para></listitem>
+ *        <listitem><para>if the sequence has less then 6 items, then items are added up to the 6th one before setting
+ *           the value to the corresponding in the 6th item of the sequence</para></listitem>
+ *     </itemizedlist>
+ *  </para></listitem>
+ *  <listitem><para>If the path corresponds to a #GdaDataModel, like for example "/ARRAY/@COLUMN/5" for the value at the
+ *     6th row of the "COLUMN" column of the "ARRAY" data model, then:
+ *     <itemizedlist>
+ *        <listitem><para>if the data model already contains 6 or more rows, then the value is just set</para></listitem>
+ *        <listitem><para>if the data model has less than 6 rows, then rows are added up to the 6th one before setting
+ *           the value</para></listitem>
+ *     </itemizedlist>
+ *  </para></listitem>
+ * </itemizedlist>
+ *
+ * Returns: TRUE if no error occurred
+ */
+gboolean
+gda_server_operation_set_value_at (GdaServerOperation *op, const gchar *value, GError **error,
+				   const gchar *path_format, ...)
+{
+	gchar *path;
+	va_list args;
+
+	Node *opnode;
+	gchar *extension = NULL;
+	gchar *colname = NULL;
+	gboolean allok = TRUE;
+
+	g_return_val_if_fail (GDA_IS_SERVER_OPERATION (op), FALSE);
+	g_return_val_if_fail (op->priv, FALSE);
+
+	/* build path */
+	va_start (args, path_format);
+	path = g_strdup_vprintf (path_format, args);
+	va_end (args);
+
+	/* set the value */
+	opnode = node_find_or_create (op, path);
+	if (!opnode) {
+		/* try to see if the "parent" is a real node */
+		gchar *str;
+		
+		str = gda_server_operation_get_node_parent (op, path);
+		if (str) {
+			opnode = node_find (op, str);
+			if (opnode) {
+				if (opnode->type != GDA_SERVER_OPERATION_NODE_PARAMLIST)
+					opnode = NULL; /* ignore opnode */
+			}
+			else {
+				gchar *str2;
+
+				str2 = gda_server_operation_get_node_parent (op, str);
+				opnode = node_find (op, str2);
+				if (opnode) {
+					if (opnode->type != GDA_SERVER_OPERATION_NODE_DATA_MODEL)
+						opnode = NULL; /* ignore opnode */
+					else 
+						colname = gda_server_operation_get_node_path_portion (op, str);
+				}
+				g_free (str2);
+			}
+			g_free (str);
+		}
+		if (opnode)
+			extension = gda_server_operation_get_node_path_portion (op, path);
+	}
+	
+	if (opnode) {
+		switch (opnode->type) {
+		case GDA_SERVER_OPERATION_NODE_PARAMLIST:
+			if (!extension) {
+				g_set_error (error, 0, 0,
+					     _("Parameterlist values can only be set for individual parameters within it"));
+				allok = FALSE;
+			}
+			else {
+				GdaParameter *param;
+				param = gda_parameter_list_find_param (opnode->d.plist, extension);
+				if (param && 
+				    !gda_parameter_set_value_str (param, value)) {
+					g_set_error (error, 0, 0,
+						     _("Could not set parameter '%s' to value '%s'"), 
+						     path, value);
+					allok = FALSE;
+				}
+			}
+			break;
+		case GDA_SERVER_OPERATION_NODE_DATA_MODEL: {
+			GdaColumn *column = NULL;
+
+			if (colname && (*colname == '@')) {
+				gint i, nbcols;
+
+				nbcols = gda_data_model_get_n_columns (opnode->d.model);
+				for (i = 0; (i<nbcols) && !column; i++) {
+					gchar *colid = NULL;
+					column = gda_data_model_describe_column (opnode->d.model, i);
+					g_object_get (G_OBJECT (column), "id", &colid, NULL);
+					if (!colid || strcmp (colid, colname +1))
+						column = NULL;
+				}
+				if (column) {
+					gchar *ptr;
+					gint row;
+					row = strtol (extension, &ptr, 10);
+					if (ptr && *ptr)
+						row = -1;
+					if (row >= 0) {
+						gint i = gda_data_model_get_n_rows (opnode->d.model);
+						
+						if (i <= row) {
+							for (; allok && (i <= row); i++) 
+								if (gda_data_model_append_row (opnode->d.model, error) < 0)
+									allok = FALSE;
+						}
+						
+						if (allok) {
+							GValue *gvalue;
+							gvalue = gda_value_new_from_string (value, 
+											    gda_column_get_g_type (column));
+							allok = gda_data_model_set_value_at (opnode->d.model,
+											     gda_column_get_position (column), 
+											     row, gvalue, error);
+							gda_value_free (gvalue);
+						}
+					}
+				}
+			}
+			break;
+		}
+		case GDA_SERVER_OPERATION_NODE_PARAM: {
+			if (!gda_parameter_set_value_str (opnode->d.param, value)) {
+				g_set_error (error, 0, 0,
+					     _("Could not set parameter '%s' to value '%s'"), 
+					     path, value);
+				allok = FALSE;
+			}
+			break;
+		}
+		case GDA_SERVER_OPERATION_NODE_SEQUENCE:
+			break;
+		case GDA_SERVER_OPERATION_NODE_SEQUENCE_ITEM:
+			break;
+		default:
+			g_assert_not_reached ();
+		}
+	}
+
+	g_free (extension);
+	g_free (colname);
+	return allok;
+}
+
 /**
  * gda_server_operation_is_valid
  * @op: a #GdaServerOperation widget
