@@ -166,6 +166,7 @@ gda_mysql_provider_class_init (GdaMysqlProviderClass *klass)
 	provider_class->perform_operation = gda_mysql_provider_perform_operation;
 
 	provider_class->execute_command = gda_mysql_provider_execute_command;
+	provider_class->execute_query = NULL;
 	provider_class->get_last_insert_id = gda_mysql_provider_get_last_insert_id;
 
 	provider_class->begin_transaction = gda_mysql_provider_begin_transaction;
@@ -174,9 +175,6 @@ gda_mysql_provider_class_init (GdaMysqlProviderClass *klass)
 	provider_class->add_savepoint = NULL;
 	provider_class->rollback_savepoint = NULL;
 	provider_class->delete_savepoint = NULL;
-	
-	provider_class->create_blob = NULL;
-	provider_class->fetch_blob = NULL;
 }
 
 static void
@@ -892,7 +890,7 @@ gda_mysql_provider_begin_transaction (GdaServerProvider *provider,
 	}
 	else {
 		/* start the transaction */
-		rc = mysql_real_query (mysql, "BEGIN", strlen ("BEGIN"));
+		rc = mysql_real_query (mysql, "BEGIN", 5);
 		if (rc != 0) {
 			event = gda_mysql_make_error (mysql);
 			gda_connection_add_event (cnc, event);
@@ -928,7 +926,7 @@ gda_mysql_provider_commit_transaction (GdaServerProvider *provider,
 		return FALSE;
 	}
 
-	rc = mysql_real_query (mysql, "COMMIT", strlen ("COMMIT"));
+	rc = mysql_real_query (mysql, "COMMIT", 6);
 	if (rc != 0) {
 		event = gda_mysql_make_error (mysql);
 		gda_connection_add_event (cnc, event);
@@ -963,7 +961,7 @@ gda_mysql_provider_rollback_transaction (GdaServerProvider *provider,
 		return FALSE;
 	}
 
-	rc = mysql_real_query (mysql, "ROLLBACK", strlen ("ROLLBACK"));
+	rc = mysql_real_query (mysql, "ROLLBACK", 8);
 	if (rc != 0) {
 		event = gda_mysql_make_error (mysql);
 		gda_connection_add_event (cnc, event);
@@ -1414,7 +1412,7 @@ get_mysql_types (GdaConnection *cnc, GdaParameterList *params)
 		{ "smallint", "", "Small integer, range is -32768 to 32767", GDA_TYPE_SHORT, NULL  },
 		{ "smallint unsigned", "", "Small unsigned integer, range is 0 to 65535", GDA_TYPE_USHORT, NULL  },
 		{ "text", "", "Text (up to 65535 characters)", GDA_TYPE_BINARY, NULL  },
-		{ "tinyint", "", "Tiny integer, range is -128 to 127", G_TYPE_CHAR, NULL  },
+		{ "tinyint", "", "Tiny integer, range is -128 to 127", G_TYPE_CHAR, "bit" },
 		{ "tinyint unsigned", "", "Tiny unsigned integer, range is 0 to 255", G_TYPE_UCHAR, NULL  },
 		{ "tinyblob", "", "Tiny blob (up to 255 bytes)", GDA_TYPE_BINARY, NULL  },
 		{ "tinytext", "", "Tiny text (up to 255 characters)", GDA_TYPE_BINARY, NULL  },		
@@ -2047,7 +2045,7 @@ get_mysql_constraints (GdaConnection *cnc, GdaParameterList *params)
 					   "REFERENCED_TABLE_NAME, REFERENCED_COLUMN_NAME "
 					   "FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE "
 					   "WHERE TABLE_NAME = '%s' AND TABLE_SCHEMA = DATABASE() AND "
-					   "CONSTRAINT_NAME != 'PRIMARY' "
+					   "CONSTRAINT_NAME != 'PRIMARY' AND REFERENCED_TABLE_NAME IS NOT NULL "
 					   "ORDER BY CONSTRAINT_NAME, ORDINAL_POSITION", 
 					   table_name);
 		rc = mysql_real_query (mysql, cmd_str, strlen (cmd_str));
@@ -2298,14 +2296,12 @@ gda_mysql_provider_get_data_handler (GdaServerProvider *provider,
 			g_object_unref (dh);
 		}
 	}
-        else if ((type == GDA_TYPE_BINARY) ||
-		 (type == GDA_TYPE_BLOB)) {
+        else if (type == GDA_TYPE_BINARY) {
 		dh = gda_server_provider_handler_find (provider, cnc, type, NULL);
 		if (!dh) {
-			dh = gda_handler_bin_new_with_prov (provider, cnc);
+			dh = gda_handler_bin_new ();
 			if (dh) {
 				gda_server_provider_handler_declare (provider, dh, cnc, GDA_TYPE_BINARY, NULL);
-				gda_server_provider_handler_declare (provider, dh, cnc, GDA_TYPE_BLOB, NULL);
 				g_object_unref (dh);
 			}
 		}
@@ -2371,10 +2367,8 @@ gda_mysql_provider_get_default_dbms_type (GdaServerProvider *provider,
 		return "bigint unsigned";
 	if (type == GDA_TYPE_BINARY)
 		return "longtext";
-	if (type == GDA_TYPE_BLOB)
-		return "oid";
 	if (type == G_TYPE_BOOLEAN)
-		return "blob";
+		return "bool";
 	if (type == G_TYPE_DATE)
 		return "date";
 	if (type == G_TYPE_DOUBLE)
