@@ -24,7 +24,7 @@
 #include <string.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
 #include <libgda/gda-log.h>
 #include <libgda/gda-util.h>
 #include <libgda-report/gda-report-item-report.h>
